<?php

namespace App\Exports;

use App\Models\Transaction;
use Illuminate\Support\Collection;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;

class TransactionExport implements FromCollection, WithHeadings
{
    /**
     * @return Collection
     */
    public function collection(): Collection
    {
        $transactions = Transaction::with('user')->whereHas('user')->orderByDesc('created_at')->get();
        $excelData = [];
        foreach ($transactions as $key => $transaction) {
            $excelData[] = [
                $key + 1,
                $transaction->driver,
                $transaction->amount,
                $transaction->user->firstname . ' ' . $transaction->user->lastname,
                $transaction->device ? 'موبایل' : 'وبسایت',
                $this->getStatus($transaction)
            ];
        }
        return collect($excelData);
    }

    /**
     * @param $status
     * @return string
     */
    protected function getStatus($status): string
    {
        switch ($status) {
            case "paid":
                return "پرداخت شده";
            case "failed":
                return "خطا در پرداخت";
            default:
                return "تراکنش ناقص";
        }
    }

    public function headings(): array
    {
        return [
            '#',
            'نام درگاه',
            'مبلغ پرداخت شده',
            'نام کاربر',
            'پلتفرم',
            'وضعیت پرداخت'
        ];
    }
}
