<?php

namespace App\Exports;

use App\Models\User;
use Illuminate\Support\Collection;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;

class UserExport implements FromCollection, WithHeadings
{
    /**
     * @return Collection
     */
    public function collection(): Collection
    {
        $users = User::with('profile')
            ->whereNull('deleted_at')
            ->get();
        $excelData = [];
        foreach ($users as $key => $user) {
            $profileExists = isset($user->profile) && !is_null($user->profile);
            $excelData[] = [
                $key + 1,
                $user->firstname . ' ' . $user->lastname,
                $user->phone_number,
                $profileExists ? $user->profile->birthdate : '---',
                $profileExists ? $this->userGender($user->profile->gender) : '---',
                $profileExists ? $user->profile->city : '---',
                $profileExists ? $user->profile->province : '---',
                $this->userStatus($user->active)
            ];
        }
        return collect($excelData);
    }

    protected function userGender($gender): string
    {
        switch ($gender) {
            case 'MALE':
                return 'آقا';
            case 'FEMALE':
                return 'خانم';
            default:
                return '---';
        }
    }

    protected function userStatus($status): string
    {
        return $status ? 'فعال' : 'غیر فعال';
    }

    public function headings(): array
    {
        return [
            '#',
            'نام و نام خانوادگی',
            'شماره موبایل',
            'تاریخ تولد',
            'جنسیت',
            'شهر',
            'استان',
            'وضعیت'
        ];
    }
}
