<?php

use App\Models\Branch;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Http\JsonResponse;
use Illuminate\Support\Facades\Schema;

if (!function_exists('jsonResponse')) {
    function jsonResponse($response): JsonResponse
    {
        if (($response['success'] ?? false)) {
            unset($response['success']);
            return response()->json($response);
        }
        return response()->json($response, 400);
    }
}

if (!function_exists('findBranch')) {
    function findBranch($id)
    {
        return Branch::query()->find($id);
    }
}

if (!function_exists('addForeignToTable')) {
    /**
     * @param $table
     * @param $column
     * @param $relationWith
     * @return JsonResponse
     */
    function addForeignToTable($table, $column, $relationWith): JsonResponse
    {
        if (Schema::hasTable($table) && Schema::hasTable($relationWith)) {
            Schema::table($table, function (Blueprint $table) use ($column, $relationWith) {
                $table->foreignId($column)->nullable()->constrained()->on($relationWith)->cascadeOnDelete();
            });
            return jsonResponse([
                'success' => true,
                'message' => 'The column was added to ' . $table . ' table successfully!'
            ]);
        }
        return jsonResponse([
            'success' => false,
            'message' => 'Table was not found...'
        ]);
    }
}

if (!function_exists('branch')) {
    /**
     * @return Branch
     */
    function branch(): Branch
    {
        return request()->branch;
    }
}

if (!function_exists('filterData')) {
    /**
     * @param array $data
     * @return array
     * @throws Exception
     */
    function filterData(array $data): array
    {
        foreach ($data as $key => $value) {
            if (!exists($value)) {
                unset($data[$key]);
            }
        }
        if (empty($data)) {
            throw new Exception('داده ای ارسال نشده است.');
        }
        return $data;

    }
}

if (!function_exists('exists')) {
    /**
     * @param mixed $data
     * @return bool
     */
    function exists($data): bool
    {
        return isset($data) && $data != '' && $data != null;
    }
}
