<?php

namespace App\Http\Controllers;

use App\Http\Requests\AboutUsRequest;
use App\Models\AboutUs;
use App\Services\AboutUs\ReadAboutUs;
use App\Services\AboutUs\UpdateOrCreateAboutUs;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Str;

class AboutUsController extends Controller
{
    public function read(ReadAboutUs $aboutUs)
    {
        $response = $aboutUs->read();
        return jsonResponse($response);
    }

    public function updateOrCreate(AboutUsRequest $request, UpdateOrCreateAboutUs $aboutUs)
    {
        $response = $aboutUs->process($request);
        return jsonResponse($response);
    }

    public function updateTitle(Request $request, $id)
    {
        $request->validate([
            'title' => 'required'
        ]);
        $title = $request->title;
        $about_us = AboutUs::query()->find($id);
        if (!$about_us) {
            return jsonResponse([
                'success' => false,
                'message' => 'این مورد یافت نشد.'
            ]);
        }
        $about_us->update([
            'title' => $title
        ]);
        return jsonResponse([
            'success' => true
        ]);
    }

    public function updateImage(Request $request, $id)
    {
        $request->validate([
            'image' => 'sometimes|image|mimes:jpeg,png,jpg,gif,svg|max:2048'
        ]);
        $image = $request->image;
        $filename = time() . '_' . Str::random(5) . '.' . $image->getClientOriginalExtension();
        Storage::putFileAs('/', $image, $filename);
        $about_us = AboutUs::query()->find($id);
        if (!$about_us) {
            return jsonResponse([
                'success' => false,
                'message' => 'این مورد یافت نشد.'
            ]);
        }
        $about_us->update([
            'image' => $filename
        ]);
        return jsonResponse([
            'success' => true
        ]);
    }

    public function updateBody(Request $request, $id)
    {
        $request->validate([
            'body' => 'required'
        ]);
        $body = $request->body;
        $about_us = AboutUs::query()->find($id);
        if (!$about_us) {
            return jsonResponse([
                'success' => false,
                'message' => 'این مورد یافت نشد.'
            ]);
        }
        $about_us->update([
            'body' => $body
        ]);
        return jsonResponse([
            'success' => true
        ]);
    }

    public function delete($id)
    {
        $about_us = AboutUs::query()->find($id);
        if (!$about_us) {
            return jsonResponse([
                'success' => false,
                'message' => 'این مورد یافت نشد.'
            ]);
        }
        $about_us->forceDelete();
        return jsonResponse([
            'success' => true
        ]);
    }

    public function handleBody(Request $request, $id)
    {
        $request->validate([
            'body' => 'required'
        ]);
        $data = $request->body;
        $about_us = AboutUs::query()->find($id);
        if (!$about_us) {
            return jsonResponse([
                'success' => false,
                'message' => 'این مورد یافت نشد.'
            ]);
        }
        $about_us->update([
            'data' => $data
        ]);
        return jsonResponse([
            'success' => true
        ]);
    }
}
