<?php

namespace App\Http\Controllers;

use App\Http\Requests\CreateAddressRequest;
use App\Http\Requests\UpdateAddressRequest;
use App\Http\Requests\UpdateWebsiteAddressRequest;
use App\Services\Address\AdminReadAddress;
use App\Services\Address\AllAddresses;
use App\Services\Address\CreateAddress;
use App\Services\Address\DeleteAddress;
use App\Services\Address\ReadAddress;
use App\Services\Address\UpdateAddress;
use Illuminate\Http\Request;

class AddressController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth:sanctum');
    }

    public function index(Request $request,AllAddresses $addresses)
    {
        $response=$addresses->all($request);
        return jsonResponse($response);
    }

    public function store(CreateAddressRequest $request,CreateAddress $address)
    {
        $response=$address->save($request);
        return jsonResponse($response);
    }

    public function show($id,Request $request,ReadAddress $address)
    {
        $response=$address->read($request,$id);
        return jsonResponse($response);
    }

    public function update(UpdateAddressRequest $request,UpdateAddress $address,$id)
    {
        $response=$address->update($request,$id);
        return jsonResponse($response);
    }

    public function destroy(Request $request,DeleteAddress $address,$id)
    {
        $response=$address->delete($request,$id);
        return jsonResponse($response);
    }

    public function adminReadAddress(AdminReadAddress $address,$id)
    {
        $response=$address->read($id);
        return jsonResponse($response);
    }

    public function userAddress(ReadAddress $address, $id)
    {
        return jsonResponse($address->userAddress($id));
    }

    public function updateAddressFromWebsite(UpdateWebsiteAddressRequest $request, UpdateAddress $address, $id)
    {
        return jsonResponse($address->updateUserAddress($request, $id));
    }

    public function deleteAddress(DeleteAddress $address, $id)
    {
        return jsonResponse($address->deleteFromWebsite($id));
    }
}
