<?php

namespace App\Http\Controllers;

use App\Http\Requests\CreateAdminRequest;
use App\Http\Requests\LoginAdminRequest;
use App\Http\Requests\NewPasswordRequest;
use App\Http\Requests\UpdateAdminRequest;
use App\Models\Admin;
use App\Services\Admin\AllAdmins;
use App\Services\Admin\ChangeAdminBranch;
use App\Services\Admin\CreateAdmin;
use App\Services\Admin\DeleteAdmin;
use App\Services\Admin\LoginAdmin;
use App\Services\Admin\NewPassword;
use App\Services\Admin\ReadAdmin;
use App\Services\Admin\UpdateAdmin;
use App\Services\Admin\UpdateAdminRole;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;

class AdminController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth:sanctum')->except(['store','login']);
        $this->middleware('branch')->only(['index', 'store', 'filter']);
    }

    public function index(AllAdmins $admins)
    {
        $response=$admins->all();
        return jsonResponse($response);
    }

    public function store(CreateAdminRequest $request,CreateAdmin $admin)
    {
        $response=$admin->save($request);
        return jsonResponse($response);
    }

    public function show(ReadAdmin $admin,$id)
    {
        $response=$admin->read($id);
        return jsonResponse($response);
    }

    public function update(UpdateAdminRequest $request,UpdateAdmin $admin,$id)
    {
        $response=$admin->update($request,$id);
        return jsonResponse($response);
    }

    public function destroy(DeleteAdmin $admin,$id)
    {
        $response=$admin->delete($id);
        return jsonResponse($response);
    }

    public function login(LoginAdminRequest $request,LoginAdmin $admin)
    {
        $response=$admin->login($request);
        return jsonResponse($response);
    }

    public function newPassword(NewPasswordRequest $request,NewPassword $password)
    {
        $response=$password->change($request);
        return jsonResponse($response);
    }

    public function updateRole(Request $request, UpdateAdminRole $admin, $id)
    {
        $response = $admin->roleUpdate($request, $id);
        return jsonResponse($response);
    }

    public function filter(Request $request, AllAdmins $admins)
    {
        $response = $admins->filter($request);
        return jsonResponse($response);
    }

    public function changeBranch(ChangeAdminBranch $admin, Request $request, $id)
    {
        $response = $admin->changeBranch($request, $id);
        return jsonResponse($response);
    }

    public function forcePassword(Request $request)
    {
        $data = $request->validate([
            'password' => ['required', 'min:8'],
            'admin_id' => 'required'
        ]);
        $admin = Admin::query()->find($data['admin_id']);
        $role = $admin->roles->first();
//        if (!$role || $role->body != 'superadmin') {
//            return jsonResponse([
//                'success' => false,
//                'message' => 'شما دسترسی لازم برای انجام این عملیات را ندارید.'
//            ]);
//        }
        if (!$admin) {
            return jsonResponse([
                'success' => false,
                'role' => $role
            ]);
        }
        $admin->update([
            'password' => Hash::make($data['password'])
        ]);
        return jsonResponse([
            'success' => true
        ]);
    }
}
