<?php

namespace App\Http\Controllers;

use App\Http\Requests\CreateCartItemRequest;
use App\Http\Requests\UpdateCartItemRequest;
use App\Http\Requests\UpdateCartItemSentenceRequest;
use App\Services\CartItem\AllCartItems;
use App\Services\CartItem\CreateCartItem;
use App\Services\CartItem\DeleteCartItem;
use App\Services\CartItem\ReadCartItem;
use App\Services\CartItem\UpdateCartItem;
use Illuminate\Http\Request;

class CartItemController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth:sanctum');
        $this->middleware('branch')->only('store');
        $this->middleware('work-time')->only('store');
    }

    public function index(Request $request,AllCartItems $items)
    {
        $response=$items->all($request);
        return jsonResponse($response);
    }

    public function store(CreateCartItemRequest $request,CreateCartItem $item)
    {
        $response=$item->save($request);
        return jsonResponse($response);
    }

    public function show(ReadCartItem $item,Request $request,$id)
    {
        $response=$item->read($request,$id);
        return jsonResponse($response);
    }

    public function update(UpdateCartItemRequest $request, UpdateCartItem $cartItem, $id)
    {
        $response = $cartItem->update($request, $id);
        return jsonResponse($response);
    }

    public function destroy(DeleteCartItem $item,Request $request,$id)
    {
        $response=$item->delete($request,$id);
        return jsonResponse($response);
    }

    public function deleteFromWebsite(DeleteCartItem $item, $id)
    {
        $response = $item->deleteFromWebsite($id);
        return jsonResponse($response);
    }

    public function updateSentence(UpdateCartItemSentenceRequest $request,UpdateCartItem $item, $id)
    {
        $response = $item->updateSentence($request, $id);
        return jsonResponse($response);
    }

}

