<?php

namespace App\Http\Controllers;

use App\Http\Requests\CreateCategoryRequest;
use App\Http\Requests\UpdateCategoryImageRequest;
use App\Http\Requests\UpdateCategoryRequest;
use App\Models\Category;
use App\Models\Product;
use App\Services\Category\AllCategories;
use App\Services\Category\CreateCategory;
use App\Services\Category\DeleteCategory;
use App\Services\Category\ReadCategory;
use App\Services\Category\UpdateCategory;
use App\Services\Category\UpdateCategoryImage;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;

class CategoryController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth:sanctum');
    }

    /**
     * @param AllCategories $categories
     * @return JsonResponse
     */
    public function index(AllCategories $categories): JsonResponse
    {
        $response=$categories->all();
        return jsonResponse($response);
    }

    /**
     * @param CreateCategory $category
     * @param CreateCategoryRequest $request
     * @return JsonResponse
     */
    public function store(CreateCategory $category, CreateCategoryRequest $request): JsonResponse
    {
        $response=$category->save($request);
        return jsonResponse($response);
    }

    /**
     * @param ReadCategory $category
     * @param $id
     * @return JsonResponse
     */
    public function show(ReadCategory $category, $id): JsonResponse
    {
        $response=$category->read($id);
        return jsonResponse($response);
    }

    /**
     * @param UpdateCategoryRequest $request
     * @param UpdateCategory $category
     * @param $id
     * @return JsonResponse
     */
    public function update(UpdateCategoryRequest $request, UpdateCategory $category, $id): JsonResponse
    {
        $response=$category->update($request,$id);
        return jsonResponse($response);
    }

    /**
     * @param Request $request
     * @param UpdateCategory $category
     * @param $id
     * @return JsonResponse
     */
    public function updateSentenceImage(Request $request, UpdateCategory $category, $id): JsonResponse
    {
        $response = $category->updateImage($request, $id);
        return jsonResponse($response);
    }

    /**
     * @param DeleteCategory $category
     * @param $id
     * @return JsonResponse
     */
    public function destroy(DeleteCategory $category, $id): JsonResponse
    {
        $response=$category->delete($id);
        return jsonResponse($response);
    }

    /**
     * @param AllCategories $categories
     * @param Request $request
     * @return JsonResponse
     */
    public function filter(AllCategories $categories, Request $request): JsonResponse
    {
        $response = $categories->filter($request);
        return jsonResponse($response);
    }

    /**
     * @param UpdateCategoryImageRequest $request
     * @param UpdateCategoryImage $category
     * @param $id
     * @return JsonResponse
     */
    public function updateCategoryImage(UpdateCategoryImageRequest $request, UpdateCategoryImage $category, $id): JsonResponse
    {
        $response = $category->update($request, $id);
        return jsonResponse($response);
    }

    /**
     * @param Request $request
     * @param $categoryId
     * @return JsonResponse
     */
    public function changePrintable(Request $request, $categoryId): JsonResponse
    {
        $data = $request->validate([
            'change_status' => 'required'
        ]);
        $category = Category::query()->find($categoryId);
        if (!$categoryId) {
            return jsonResponse([
                'success' => false,
                'message'=> 'دسته بندی مورد نظر یافت نشد'
            ]);
        }
        $category->update([
            'printable' => $data['change_status']
        ]);
        Product::query()->where('category_id', $categoryId)->update([
            'printable' => $data['change_status']
        ]);
        return jsonResponse([
            'success' => true
        ]);
    }
}
