<?php

namespace App\Http\Controllers;

use App\Http\Requests\FilterRequest;
use App\Models\CoffeeType;
use App\Services\Filter\AllFilters;
use App\Services\Filter\CreateFilter;
use App\Services\Filter\DeleteFilter;
use App\Services\Filter\UpdateFilter;
use Illuminate\Http\JsonResponse;

class CoffeeTypeController extends Controller
{
    protected $model;
    public function __construct()
    {
        $this->middleware('auth:sanctum');
        $this->model = new CoffeeType();
    }

    /**
     * @return JsonResponse
     */
    public function index(): JsonResponse
    {
        $filters = new AllFilters($this->model);
        return jsonResponse($filters->all());
    }

    /**
     * @param FilterRequest $request
     * @return JsonResponse
     */
    public function store(FilterRequest $request): JsonResponse
    {
        $filter = new CreateFilter($this->model);
        return jsonResponse($filter->create($request));
    }

    /**
     * @param FilterRequest $request
     * @param $id
     * @return JsonResponse
     */
    public function update(FilterRequest $request, $id): JsonResponse
    {
        $filter = new UpdateFilter($this->model);
        return jsonResponse($filter->update($request, $id));
    }

    /**
     * @param $id
     * @return JsonResponse
     */
    public function destroy($id): JsonResponse
    {
        $filter = new DeleteFilter($this->model);
        return jsonResponse($filter->delete($id));
    }
}
