<?php

namespace App\Http\Controllers;

use App\Http\Requests\CreateFaqRequest;
use App\Http\Requests\UpdateFaqRequest;
use App\Services\Faq\AllFaqs;
use App\Services\Faq\CreateFaq;
use App\Services\Faq\DeleteFaq;
use App\Services\Faq\FindFaq;
use App\Services\Faq\UpdateFaq;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;

class FaqController extends Controller
{
    /**
     * @param Request $request
     * @param AllFaqs $faqs
     * @return JsonResponse
     */
    public function index(Request $request, AllFaqs $faqs): JsonResponse
    {
        return jsonResponse($faqs->all($request));
    }

    /**
     * @param CreateFaqRequest $request
     * @param CreateFaq $faq
     * @return JsonResponse
     */
    public function store(CreateFaqRequest $request, CreateFaq $faq): JsonResponse
    {
        return jsonResponse($faq->create($request));
    }

    /**
     * @param $id
     * @param FindFaq $faq
     * @return JsonResponse
     */
    public function show($id, FindFaq $faq): JsonResponse
    {
        return jsonResponse($faq->find($id));
    }

    /**
     * @param UpdateFaqRequest $request
     * @param UpdateFaq $faq
     * @param $id
     * @return JsonResponse
     */
    public function update(UpdateFaqRequest $request, UpdateFaq $faq, $id): JsonResponse
    {
        return jsonResponse($faq->update($request, $id));
    }

    /**
     * @param DeleteFaq $faq
     * @param $id
     * @return JsonResponse
     */
    public function destroy(DeleteFaq $faq, $id): JsonResponse
    {
        return jsonResponse($faq->delete($id));
    }
}
