<?php

namespace App\Http\Controllers;

use App\Models\BeanType;
use App\Models\CoffeeType;
use App\Models\GrowthPart;
use App\Models\MillType;
use App\Models\ProductMeta;
use App\Services\Filter\AllFilters;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;

class FilterController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth:sanctum');
    }

    /**
     * @param GrowthPart $growthPart
     * @param CoffeeType $coffeeType
     * @param BeanType $beanType
     * @param MillType $millType
     * @return JsonResponse
     */
    public function index(GrowthPart $growthPart, CoffeeType $coffeeType, BeanType $beanType, MillType $millType): JsonResponse
    {
        $growthParts = (new AllFilters($growthPart))->all();
        $coffeeTypes = (new AllFilters($coffeeType))->all();
        $beanTypes = (new AllFilters($beanType))->all();
        $millTypes = (new AllFilters($millType))->all();
        $this->fluentResponse($growthParts, $coffeeTypes, $beanTypes, $millTypes);
        return jsonResponse([
            'success' => true,
            'filters' => [
                'growthParts' => $growthParts,
                'coffeeTypes' => $coffeeTypes,
                'beanTypes' => $beanTypes,
                'millTypes' => $millTypes
            ]
        ]);
    }

    public function fluentResponse(&$arr1, &$arr2, &$arr3, &$arr4)
    {
        unset($arr1['success']);
        unset($arr2['success']);
        unset($arr3['success']);
        unset($arr4['success']);
    }

    public function updateFilters(Request $request, $id)
    {
        $data = $request->validate([
            'bean_type_id' => 'nullable',
            'coffee_type_id' => 'nullable',
            'mill_type_id' => 'nullable',
            'growth_part_id' => 'nullable'
        ]);
        foreach ($data as $key => $value) {
            if (!isset($value) || $value == null || $value == '') {
                unset($data[$key]);
            }
        }
        if (empty($data)) {
            return jsonResponse([
                'success' => false
            ]);
        }
        if (isset($data['bean_type_id'])) {
            ProductMeta::query()
                ->where('product_id', $id)
                ->where('filter_type', BeanType::class)
                ->update([
                    'filter_id' => $data['bean_type_id']
                ]);
        }
        if (isset($data['coffee_type_id'])) {
            ProductMeta::query()
                ->where('product_id', $id)
                ->where('filter_type', CoffeeType::class)
                ->update([
                    'filter_id' => $data['coffee_type_id']
                ]);
        }
        if (isset($data['mill_type_id'])) {
            ProductMeta::query()
                ->where('product_id', $id)
                ->where('filter_type', MillType::class)
                ->update([
                    'filter_id' => $data['mill_type_id']
                ]);
        }
        if (isset($data['growth_part_id'])) {
            ProductMeta::query()
                ->where('product_id', $id)
                ->where('filter_type', GrowthPart::class)
                ->update([
                    'filter_id' => $data['growth_part_id']
                ]);
        }
        return jsonResponse([
            'success' => true
        ]);
    }
}
