<?php

namespace App\Http\Controllers;

use App\Models\FooterProduct;
use App\Models\Product;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;

class FooterProductController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth:sanctum');
    }

    /**
     * @return JsonResponse
     */
    public function all(): JsonResponse
    {
        $footerProducts = FooterProduct::with('product')->get();
        return jsonResponse([
            'success' => true,
            'footer_products' => $footerProducts
        ]);
    }

    /**
     * @param Request $request
     * @return JsonResponse
     */
    public function updateOrCreateFooterProducts(Request $request): JsonResponse
    {
        $data = $request->validate([
            'product_ids' => ['required', 'array']
        ]);
        foreach ($data['product_ids'] as $product_id) {
            $product = Product::query()->find($product_id);
            if (!$product) {
                return jsonResponse([
                    'success' => false,
                    'message' => 'محصول مورد نظر یافت نشد'
                ]);
            }
            $updateValue = ['product_id' => $product_id];
            FooterProduct::query()->updateOrCreate($updateValue, $updateValue);
        }
        return jsonResponse([
            'success' => true
        ]);
    }

    /**
     * @param $id
     * @return JsonResponse
     */
    public function destroy($id): JsonResponse
    {
        $footerProduct = FooterProduct::query()->find($id);
        if (!$footerProduct) {
            return jsonResponse([
                'success' => false,
                'message' => 'محصول مورد نظر یافت نشد'
            ]);
        }
        $footerProduct->delete();
        return jsonResponse([
            'success' => true
        ]);
    }
}
