<?php

namespace App\Http\Controllers;

use App\Http\Requests\CreateNotificationRequest;
use App\Http\Requests\UpdateNotificationRequest;
use App\Services\Notification\AllNotif;
use App\Services\Notification\AllNotifications;
use App\Services\Notification\CreateNotification;
use App\Services\Notification\CreateNotificationForUser;
use App\Services\Notification\DeleteById;
use App\Services\Notification\DeleteNotification;
use App\Services\Notification\MarkAsRead;
use App\Services\Notification\ReadNotification;
use App\Services\Notification\UpdateNotification;
use App\Services\Notification\UserNotifications;
use Illuminate\Http\Request;

class NotificationController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth:sanctum');
    }

    public function index(Request $request,AllNotifications $notifications)
    {
        $response=$notifications->all($request);
        return jsonResponse($response);
    }

    public function store(CreateNotificationRequest $request,CreateNotification $notification)
    {
        $response=$notification->save($request);
        return jsonResponse($response);
    }

    public function show(Request $request,ReadNotification $notification,$id)
    {
        $response=$notification->read($request,$id);
        return jsonResponse($response);
    }

    public function update(UpdateNotificationRequest $request,UpdateNotification $notification,$id)
    {
        $response=$notification->update($request,$id);
        return jsonResponse($response);
    }

    public function destroy(Request $request,DeleteNotification $notification,$id)
    {
        $response=$notification->delete($request,$id);
        return jsonResponse($response);
    }

    public function mark_as_read(Request $request,MarkAsRead $notification)
    {
        $response=$notification->mark_as_read($request);
        return jsonResponse($response);
    }

    public function userNotifications(UserNotifications $notifications,$id)
    {
        $response=$notifications->all($id);
        return jsonResponse($response);
    }

    public function forUser(Request $request, CreateNotificationForUser $notification,$id)
    {
        $response = $notification->create($request,$id);
        return jsonResponse($response);
    }

    public function all(AllNotif $notification)
    {
        $response = $notification->all();
        return jsonResponse($response);
    }

    public function deleteById(DeleteById $notification, $id)
    {
        $response = $notification->delete($id);
        return jsonResponse($response);
    }

    public function dispatchNotifications(CreateNotification $notification, Request $request)
    {
        $response = $notification->dispatch($request);
        return jsonResponse($response);
    }

    public function dispatchNotificationAll(CreateNotification $notification, Request $request)
    {
        $response = $notification->dispatchAll($request);
        return jsonResponse($response);
    }
}
