<?php

namespace App\Http\Controllers;

use App\Models\Order;
use App\Models\OrderItem;
use Illuminate\Http\Request;

class PDFConverterController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth:sanctum');
    }

    public function orders(Request $request)
    {
        $orders = Order::with(['transaction', 'orderItems'])
            ->whereHas('transaction', function ($q) {
                $q->where('status', 'paid');
            })
            ->whereHas('orderItems', function ($q) {
                $q->whereNotNull('sentence');
            })
            ->where('printed', '=', false)
            ->where('active', '=', true)
            ->latest();
        $admin = $request->user();
        throw_if($admin->branch_id == null);

        $isSuperAdmin = $admin->id == 1;

        $currentBranchOrders = $isSuperAdmin ? $orders->get() : $orders->where('branch_id', $admin->branch_id)->get();

        $response = [
            'success' => true,
            'orders' => $currentBranchOrders,
        ];
        return jsonResponse($response);
    }

    public function changeStatus(Request $request)
    {
        $request->validate([
            'order_item_ids' => 'required'
        ]);
        $order_item_ids = $request->order_item_ids;
        OrderItem::query()->whereIn('id', $order_item_ids)->update([
            'printed' => true
        ]);
        $orders = Order::query()->where('active', true)->where('printed', false)->get();
        foreach ($orders as $order) {
            $printed_item_count = $order->orderItems()->where('printed', true)->get()->count();
            $order_item_count = $order->orderItems()->whereNotNull('sentence')->get()->count();
            if ($order_item_count - $printed_item_count == 0) {
                $order->update([
                    'printed' => true
                ]);
            }
        }

        return jsonResponse([
            'success' => true
        ]);
    }
}
