<?php

namespace App\Http\Controllers;

use App\Models\Branch;
use App\Models\Product;
use Illuminate\Http\Request;
use Illuminate\Support\Collection;

class SearchController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth:sanctum')->except('webSearch');
        $this->middleware('branch')->except('webSearch');
    }

    public function search(Request $request)
    {
        $search = $request->q;
        if ($search == null) {
            return response()->json([
                'success' => true,
                'products' => []
            ]);
        }
        $products = Product::query()->where('name', 'like', '%' . $search . '%')->get();

        return response()->json([
            'success' => true,
            'products' => $products
        ]);
    }

    public function webSearch(Request $request)
    {
        $search = $request->search;
        if ($search == null) {
            return response()->json([
                'success' => true,
                'products' => []
            ]);
        }
        $branches = Branch::query()->where('active', true)->with(['products' => function($q) use ($search) {
            $q->where('name', 'like', '%' . $search . '%')->whereNull('deleted_at');
        }])->get();
        $selectedBranches = new Collection();
        foreach ($branches as $branch) {
            if ($branch->products->count() !== 0) {
                $selectedBranches->add($branch);
            }
        }
        return jsonResponse([
            'success' => true,
            'branches' => $selectedBranches
        ]);

    }
}
