<?php

namespace App\Http\Controllers;

use App\Exports\SentenceExport;
use App\Http\Requests\CreateSentenceRequest;
use App\Http\Requests\UpdateSentenceRequest;
use App\Services\Sentence\AllSentences;
use App\Services\Sentence\AppAllCategories;
use App\Services\Sentence\AppAllSentences;
use App\Services\Sentence\CreateSentence;
use App\Services\Sentence\DeleteSentence;
use App\Services\Sentence\ReadSentence;
use App\Services\Sentence\SentenceCategories;
use App\Services\Sentence\UpdateSentence;
use Illuminate\Http\Request;
use Maatwebsite\Excel\Facades\Excel;
use Symfony\Component\HttpFoundation\BinaryFileResponse;

class SentenceController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth:sanctum');
    }

    public function index(AllSentences $sentences,Request $request)
    {
        $response=$sentences->all($request);
        return jsonResponse($response);
    }

    public function store(CreateSentenceRequest $request,CreateSentence $sentence)
    {
        $response=$sentence->save($request);
        return jsonResponse($response);
    }

    public function show($id,ReadSentence $sentence)
    {
        $response=$sentence->read($id);
        return jsonResponse($response);
    }

    public function update(UpdateSentence $sentence,UpdateSentenceRequest $request,$id)
    {
        $response=$sentence->update($request,$id);
        return jsonResponse($response);
    }

    public function destroy(DeleteSentence $sentence,$id)
    {
        $response=$sentence->delete($id);
        return jsonResponse($response);
    }

    public function sentence_categories(SentenceCategories $categories)
    {
        $response=$categories->show();
        return jsonResponse($response);
    }

    public function appAllSentences(AppAllSentences $sentences)
    {
        $response = $sentences->all();
        return jsonResponse($response);
    }

    public function appAllCategories(AppAllCategories $categories)
    {
        $response = $categories->all();
        return jsonResponse($response);
    }

    public function filter(AppAllSentences $sentences, Request $request)
    {
        $response = $sentences->filter($request);
        return jsonResponse($response);
    }

    public function sentenceCategoryEdit(UpdateSentence $sentence, Request $request, $id)
    {
        $response = $sentence->edit($request, $id);
        return jsonResponse($response);
    }

    public function sentenceTagEdit(UpdateSentence $sentence, Request $request, $id)
    {
        $response = $sentence->tagEdit($request,$id);
        return jsonResponse($response);
    }

    /**
     * @return BinaryFileResponse
     */
    public function excelExport(): BinaryFileResponse
    {
        return Excel::download(new SentenceExport(), 'sentences.xlsx');
    }
}
