<?php

namespace App\Http\Controllers;

use App\Http\Requests\SetBranchConfigRequest;
use App\Services\Settings\ReadSettings;
use App\Services\Settings\SetUrl;
use App\Services\Settings\UpdateSettings;
use Illuminate\Http\JsonResponse;

class SettingsController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth:sanctum')->except('read');
    }

    /**
     * @param SetUrl $url
     * @param SetBranchConfigRequest $request
     * @return JsonResponse
     */
    public function settings(SetUrl $url, SetBranchConfigRequest $request): JsonResponse
    {
        $response=$url->setUrl($request);
        return jsonResponse($response);
    }

    /**
     * @param ReadSettings $settings
     * @return JsonResponse
     */
    public function read(ReadSettings $settings): JsonResponse
    {
        $response = $settings->read();
        return jsonResponse($response);
    }

    /**
     * @param SetBranchConfigRequest $request
     * @param UpdateSettings $settings
     * @return JsonResponse
     */
    public function update(SetBranchConfigRequest $request, UpdateSettings $settings): JsonResponse
    {
        $response = $settings->update($request);
        return jsonResponse($response);
    }
}
