<?php

namespace App\Http\Controllers;

use App\Exports\SupportExport;
use App\Http\Requests\SupportRequest;
use App\Mail\SupportMail;
use App\Models\Support;
use Exception;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Mail;
use Kavenegar\KavenegarApi;
use Maatwebsite\Excel\Facades\Excel;
use Symfony\Component\HttpFoundation\BinaryFileResponse;

class SupportController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth:sanctum');
    }

    public function showAll(): JsonResponse
    {
        $supportItems = Support::with('user')->latest()->paginate(10);
        return jsonResponse(
            [
                'success' => true,
                'support_items' => $supportItems
            ]
        );
    }

    public function send(SupportRequest $request): JsonResponse
    {
        $support = Support::query()->create($request->validated() + ['user_id' => $request->user()->id]);
        return jsonResponse(
            [
                'success' => true,
                'support' => $support,
                'message' => 'درخواست شما با موفقیت ثبت شد'
            ]
        );
    }

    public function toggleSupport(Request $request, $id): JsonResponse
    {
        $request->validate([
            'message' => 'sometimes'
        ]);
        $message = $request->message;
        $support = Support::query()->find($id);
        if (!$support) {
            return jsonResponse(
                [
                    'success' => false,
                    'message' => 'این مورد یافت نشد.'
                ]
            );
        }
        if ($request->has('message')) {
            $support->update([
                'answer' => $message
            ]);
            if (!is_null($support->email)) {
                try {
                    Mail::to($support->email)->send(new SupportMail($message));
                } catch (Exception $exception) {
                    $support->update([
                        'status' => 'ANSWERED'
                    ]);
                    return jsonResponse([
                        'success' => true,
                        'message' => 'عملیات موفقیت آمیز بود، ولی به دلیل نامعتبر بودن ایمیل پاسخی ارسال نشد.'
                    ]);
                }
            }
            if (!is_null($support->phone_number)){
                $user = $support->user;
                $sms = new KavenegarApi(config('kavenegar.apikey'));
                $sms->VerifyLookup($support->phone_number, $user->firstname, null, null, 'SUPPORT');
            }
        }
        $support->update([
            'status' => 'ANSWERED'
        ]);
        return jsonResponse(
            [
                'success' => true,
                'message' => 'عملیات موفقیت آمیز بود.'
            ]
        );
    }

    /**
     * @return BinaryFileResponse
     */
    public function export(): BinaryFileResponse
    {
        return Excel::download(new SupportExport(), 'supports.xlsx');
    }
}
