<?php

namespace App\Http\Controllers;

use App\Exports\TransactionExport;
use App\Services\OrderItem\CreateOrderItem;
use App\Services\Transaction\AllTransactions;
use App\Services\Transaction\ConfirmGateway;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;
use Maatwebsite\Excel\Facades\Excel;
use Symfony\Component\HttpFoundation\BinaryFileResponse;

class TransactionController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth:sanctum')->except('confirm');
    }

    public function index(AllTransactions $transactions): JsonResponse
    {
        $response = $transactions->all();
        return jsonResponse($response);
    }

    public function payment(Request $request, CreateOrderItem $gateway): JsonResponse
    {
        $response = $gateway->payment($request);
        return jsonResponse($response);
    }

    public function confirm(Request $request, ConfirmGateway $gateway): JsonResponse
    {
        $response = $gateway->confirm($request);
        return jsonResponse($response);
    }

    /**
     * @return BinaryFileResponse
     */
    public function export(): BinaryFileResponse
    {
        return Excel::download(new TransactionExport(), 'transactions.xlsx');
    }
}
