<?php

namespace App\Http\Controllers;

use App\Codes\CodeGenerator;
use App\Http\Requests\CreateUserRequest;
use App\Http\Requests\UpdateUserRequest;
use App\Services\User\ActivateUser;
use App\Services\User\AllUsers;
use App\Services\User\AuthUser;
use App\Services\User\CreateUser;
use App\Services\User\DeactivateUser;
use App\Services\User\DeleteUser;
use App\Services\User\ReadUser;
use App\Services\User\ToggleActivation;
use App\Services\User\UpdateUser;
use App\Services\User\UpdateUserFromAdmin;
use App\Services\User\UserExcelExport;
use App\Services\User\UserReferrals;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Collection;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\BinaryFileResponse;

class UserController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth:sanctum')->except('store');
    }

    public function authUser(AuthUser $user, Request $request)
    {
        return jsonResponse($user->authUser($request));
    }

    public function index(AllUsers $users)
    {
        $response = $users->all();
        return jsonResponse($response);
    }

    public function show(ReadUser $user, $id)
    {
        $response = $user->read($id);
        return jsonResponse($response);
    }

    public function store(CreateUserRequest $request, CreateUser $user, CodeGenerator $generator)
    {
        $response = $user->save($request, $generator);
        return jsonResponse($response);
    }

    public function update(UpdateUserRequest $request, UpdateUser $user)
    {
        $response = $user->update($request);
        return jsonResponse($response);
    }

    public function destroy(DeleteUser $user, $id)
    {
        $response = $user->delete($id);
        return jsonResponse($response);
    }

    public function activate(ActivateUser $user, $id)
    {
        $response = $user->activate($id);
        return jsonResponse($response);
    }

    public function deactivate(DeactivateUser $user, $id)
    {
        $response = $user->deactivate($id);
        return jsonResponse($response);
    }

    public function updateUserFromPanel(Request $request, UpdateUserFromAdmin $user, $id)
    {
        $response = $user->updateFromAdmin($request, $id);
        return jsonResponse($response);
    }

    public function referrals(UserReferrals $user, $id)
    {
        $response = $user->referrals($id);
        return jsonResponse($response);
    }

    public function toggleActivation(ToggleActivation $activation, $id)
    {
        $response = $activation->toggle($id);
        return jsonResponse($response);
    }

    public function filter(Request $request, AllUsers $users)
    {
        $response = $users->filter($request);
        return jsonResponse($response);
    }

    /**
     * @param UserExcelExport $excel
     * @return BinaryFileResponse
     */
    public function excelExport(UserExcelExport $excel): BinaryFileResponse
    {
        return $excel->export();
    }
}
