<?php

namespace App\Http\Controllers;

use App\Models\WebsiteSlider;
use App\Services\WebsiteSlider\All;
use App\Services\WebsiteSlider\CreateWbSlider;
use App\Services\WebsiteSlider\DeleteWbSlider;
use App\Services\WebsiteSlider\UpdateWbSlider;
use Illuminate\Http\Request;
use Illuminate\Validation\Rule;

class WebsiteSliderController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth:sanctum');
    }

    public function index(All $all)
    {
        $response = $all->all();
        return jsonResponse($response);
    }

    public function store(Request $request, CreateWbSlider $slider)
    {
        $request->validate([
            'image' => 'required|image|mimes:jpeg,png,jpg,gif,svg'
        ]);
        $response = $slider->create($request);
        return jsonResponse($response);
    }

    public function update(Request $request, UpdateWbSlider $slider, $id)
    {
        $request->validate([
            'image' => 'required|image|mimes:jpeg,png,jpg,gif,svg'
        ]);
        $response = $slider->update($request, $id);
        return jsonResponse($response);
    }

    public function destroy(DeleteWbSlider $slider, $id)
    {
        return jsonResponse($slider->delete($id));
    }

    public function setPriority(Request $request)
    {
        $request->validate([
            'priority' => 'required',
            'slider_id' => ['required', Rule::exists('website_sliders', 'id')]
        ]);
        $slider = WebsiteSlider::query()->find($request->slider_id);
        $slider->update([
            'priority' => $request->priority
        ]);
        return jsonResponse([
            'success' => true
        ]);

    }
}
