<?php

namespace App\Listeners;

use App\Classes\Credit;
use App\Codes\CodeHandler;
use App\Events\CreditEvent;
use App\Models\Rank;
use App\Models\User;

class CreditListener
{
    protected $generator;

    /**
     * Create the event listener.
     *
     * @return void
     */
    public function __construct()
    {
        $this->generator = new CodeHandler();
    }

    /**
     * Handle the event.
     *
     * @param CreditEvent $event
     * @return void
     */
    public function handle(CreditEvent $event)
    {
        $transaction = $event->getTransaction();
        $user = $transaction->getUser();
        $amount = $transaction->getAmount();
        $creditsToBeAdded = ($amount / 50000) * 500;
        $operation = new Credit();
        $userCredits = $operation->setUser($user)->increment($creditsToBeAdded)->result();
        $this->handlePromotion($user, $userCredits);
        $this->handleUserRank($user, $userCredits);
    }

    protected function handlePromotion(User $user, $userCredits)
    {
        if ($userCredits >= 10000) {
            $user->promotions()->create([
                'promotion_code' => $this->generator->promotionCode(),
                'percent' => 10,
                'max_promo_limit' => 50000
            ]);
        }
    }

    /**
     * @param $user
     * @param $credit
     * @return bool
     */
    protected function handleUserRank($user, $credit): bool
    {
        $ranks = Rank::query()->orderByDesc('price')->get();
        foreach ($ranks as $rank) {
            if ($credit >= $rank->credit_limit) {
                $pivot = $user->ranks()->create([
                    'rank_id' => $rank->id
                ]);
                $currentRank = Rank::query()->find($pivot->rank_id);
                $user->credit()->update(
                    [
                        'value' => $credit - $currentRank->getAttribute('credit_limit')
                    ]
                );
                return true;
            }
        }
        return false;
    }
}
