<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Str;
use Laravel\Sanctum\HasApiTokens;

class Branch extends Model
{
    use HasFactory, HasApiTokens;

    const TYPES = ['CAFE', 'STORE'];

    protected $guarded = [];

    /**
     * @return BelongsToMany
     */
    public function products(): BelongsToMany
    {
        return $this->belongsToMany(Product::class, 'branch_product');
    }

    /**
     * @return HasMany
     */
    public function users(): HasMany
    {
        return $this->hasMany(User::class, 'branch_id');
    }

    /**
     * @return HasMany
     */
    public function admins(): HasMany
    {
        return $this->hasMany(Admin::class, 'branch_id');
    }

    /**
     * @return HasMany
     */
    public function orders(): HasMany
    {
        return $this->hasMany(Order::class, 'branch_id');
    }

    /**
     * @param $value
     * @return string
     */
    public function getBranchImageAttribute($value): string
    {
        return Str::contains($value, 'http') ? $value : Storage::url($value);
    }

    /**
     * @return HasMany
     */
    public function limitations(): HasMany
    {
        return $this->hasMany(Limitation::class, 'branch_id');
    }
}
