<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\Relations\MorphToMany;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Support\Facades\Storage;
use Laravel\Sanctum\HasApiTokens;

class Category extends Model
{
    use HasFactory, HasApiTokens, SoftDeletes;

    protected $guarded = [];

    /**
     * @param $value
     * @return string
     */
    public function getActiveImageAttribute($value): string
    {
        return Storage::url($value);
    }

    /**
     * @param $value
     * @return string
     */
    public function getPassiveImageAttribute($value): string
    {
        return Storage::url($value);
    }

    /**
     * @return MorphToMany
     */
    public function sentences(): MorphToMany
    {
        return $this->morphedByMany(Sentence::class, 'category');
    }

    /**
     * @return MorphToMany
     */
    public function products(): MorphToMany
    {
        return $this->morphedByMany(Product::class, 'category');
    }

    /**
     * @return HasMany
     */
    public function tags(): HasMany
    {
        return $this->hasMany(Tag::class, 'category_id');
    }

    /**
     * @return bool
     */
    public function isCafe(): bool
    {
        return $this->type == 'CAFE';
    }

    /**
     * @return HasMany
     */
    public function limitations(): HasMany
    {
        return $this->hasMany(Limitation::class, 'category_id');
    }
}
