<?php

namespace App\Models;

use Carbon\Carbon;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Support\Collection;
use Laravel\Sanctum\HasApiTokens;

class Order extends Model
{
    use HasFactory, HasApiTokens, SoftDeletes;

    protected $guarded = [];
    protected $appends = ['has_store_product', 'has_cafe_product'];

    public function getCreatedAtAttribute($date)
    {
        $verta = verta($date);
        $verta->timezone('Asia/tehran');
        return $verta->format('Y/m/d - H:i:s');
    }

    public function user()
    {
        return $this->belongsTo(User::class, 'user_id');
    }

    public function address()
    {
        return $this->belongsTo(Address::class, 'address_id');
    }

    public function orderItems()
    {
        return $this->hasMany(OrderItem::class, 'order_id');
    }

    public function transaction()
    {
        return $this->hasOne(Transaction::class, 'order_id');
    }

    public function branch()
    {
        return $this->belongsTo(Branch::class, 'branch_id');
    }

    public function getHasStoreProductAttribute()
    {
        return $this->orderItems()->get()->search(function ($item) {
            return $item->is_store_product;
        }) !== false;
    }

    public function getHasCafeProductAttribute()
    {
        return $this->orderItems()->get()->search(function ($item) {
                return !$item->is_store_product;
            }) !== false;
    }
}
