<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\HigherOrderBuilderProxy;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\Relations\HasOne;
use Illuminate\Database\Eloquent\SoftDeletes;
use Laravel\Sanctum\HasApiTokens;

class User extends Model
{
    protected $guarded=['id'];
    use HasFactory,HasApiTokens,SoftDeletes;

    protected $appends = ['user_rank'];

    /**
     * @return int
     */
    public function getUserRankAttribute(): int
    {
        $lastRank = $this->ranks->first();
        if (is_null($lastRank)) {
            return 0;
        }
        switch ($lastRank->criteria) {
            case "سطح برنزی":
                return 1;
            case "سطح نقره ای":
                return 2;
            case "سطح طلایی":
                return 3;
            default:
                return 4;
        }
    }

    /**
     * @return HasMany
     */
    public function addresses(): HasMany
    {
        return $this->hasMany(Address::class,'user_id');
    }

    /**
     * @return HasMany
     */
    public function notifications(): HasMany
    {
        return $this->hasMany(Notification::class,'user_id');
    }

    /**
     * @return HasMany
     */
    public function cartItems(): HasMany
    {
        return $this->hasMany(CartItem::class,'user_id');
    }

    /**
     * @return HasMany
     */
    public function orders(): HasMany
    {
        return $this->hasMany(Order::class,'user_id');
    }

    /**
     * @return HasMany
     */
    public function promotions(): HasMany
    {
        return $this->hasMany(Promotion::class,'user_id');
    }

    /**
     * @return HasMany
     */
    public function referrals(): HasMany
    {
        return $this->hasMany(Referral::class,'user_id');
    }

    /**
     * @return HasMany
     */
    public function transactions(): HasMany
    {
        return $this->hasMany(Transaction::class, 'user_id');
    }

    /**
     * @return BelongsTo
     */
    public function branch(): BelongsTo
    {
        return $this->belongsTo(Branch::class, 'branch_id');
    }

    /**
     * @return HasOne
     */
    public function profile(): HasOne
    {
        return $this->hasOne(Profile::class, 'user_id');
    }

    /**
     * @return HasOne
     */
    public function credit(): HasOne
    {
        return $this->hasOne(Credit::class, 'user_id');
    }

    /**
     * @return BelongsToMany
     */
    public function ranks(): BelongsToMany
    {
        return $this->belongsToMany(Rank::class, 'ranks_users');
    }

    /**
     * @return HigherOrderBuilderProxy|int|mixed|null
     */
    public function getRankPromotionAttribute()
    {
        switch ($this->user_rank) {
            case 0:
                return 0;
            case 1:
                return Rank::query()->where('criteria', '=', 'سطح برنزی')->first()->promotion;
            case 2:
                return Rank::query()->where('criteria', '=', 'سطح نقره ای')->first()->promotion;
            case 3:
                return Rank::query()->where('criteria', '=', 'سطح طلایی')->first()->promotion;
            default:
                return null;
        }
    }

    /**
     * @return HasMany
     */
    public function rates(): HasMany
    {
        return $this->hasMany(Rate::class, 'user_id');
    }

    /**
     * @return HasMany
     */
    public function supports(): HasMany
    {
        return $this->hasMany(Support::class, 'user_id');
    }
}
