<?php


namespace App\Services\AboutUs;


use App\Http\Requests\AboutUsRequest;
use App\Models\AboutUs;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Str;

class UpdateOrCreateAboutUs
{
    public function process(AboutUsRequest $request)
    {
        $request->validated();
        $title = $request->title;
        $data = $request->data;
        if ($request->has('image')) {
            $image = $request->image;
            $filename = time() . '_' . Str::random(5) . '.' . $image->getClientOriginalExtension();
            Storage::putFileAs('/', $image, $filename);
            return [
                'success' => true,
                'about_us' => $this->createAboutUs($title, $data, $filename)
            ];
        }
        return [
            'success' => true,
            'about_us' => $this->createAboutUs($title, $data)
        ];
    }

    protected function createAboutUs($title, $data, $image = null)
    {
        $first_values = [
            'data' => $data,
            'title' => $title
        ];
        $second_values = [
            'data' => $data,
            'title' => $title,
            'image' => $image
        ];
        return $image == null ?
            AboutUs::query()->updateOrCreate($first_values, $first_values)
            :
            AboutUs::query()->updateOrCreate($first_values, $second_values);
    }
}
