<?php


namespace App\Services\Admin;


use App\Http\Requests\CreateAdminRequest;
use App\Models\Admin;
use App\Models\Role;
use Illuminate\Support\Facades\Hash;

class CreateAdmin
{
    protected $branch = null;

    public function __construct()
    {
        $this->branch = findBranch(request()->header('x-branch-id') != 0 ? request()->header('x-branch-id') : null);
    }

    public function save(CreateAdminRequest $request)
    {
        $data = $request->validated();
        $role = Role::query()->find($data['role_id']);
        if (!$role) {
            return [
                'success' => false,
                'message' => 'نقش مورد نظر یافت نشد'
            ];
        }
        if (Admin::query()->where('email', $data['email'])
                ->where('deleted_at', null)
                ->first() || Admin::query()->where('username', $data['username'])
                ->where('deleted_at', null)
                ->first()
        ) {
            return [
                'success' => false,
                'message' => 'ادمینی با این مشخصات موجود است'
            ];
        }
        if ($this->branch == null) {
            $admin = $role->admins()->create([
                'username' => $data['username'],
                'email' => $data['email'],
                'password' => Hash::make($data['password']),
            ]);
        } else {
            $admin = $role->admins()->create([
                'username' => $data['username'],
                'email' => $data['email'],
                'password' => Hash::make($data['password']),
                'branch_id' => $this->branch->id
            ]);
        }

        $token = $admin->createToken('ApiToken')->plainTextToken;
        return [
            'success' => true,
            'admin' => $admin,
            'token' => $token,
            'message' => 'ادمین با موفقیت ایجاد شد'
        ];

    }
}
