<?php


namespace App\Services\CartItem;


use App\Http\Requests\CreateCartItemRequest;
use App\Models\Category;
use App\Models\Limitation;
use App\Models\Product;
use App\Models\Sentence;
use App\Models\Size;

class CreateCartItem
{
    public function save(CreateCartItemRequest $request): array
    {

        $data = $request->validated();
        $user = $request->user();
        if (!$this->allHaveSameBranch($request)) {
            return [
                'success' => false,
                'message' => 'محصولات سبد خرید باید همگی از یک شعبه یکسان باشند.'
            ];
        }
        $product = Product::query()->find($data['product_id']);
        if (!$product) {
            return [
                'success' => false,
                'message' => 'محصول مورد نظر یافت نشد',
            ];
        }
        $productCategory = Category::query()->where('id', $product->category_id)->first();
        $limitation = Limitation::query()
            ->where('branch_id', branch()->id)
            ->where('category_id', $productCategory->id)
            ->first();
        if (!is_null($limitation) && $limitation->quantity - $data['quantity'] < 0) {
            return [
                'success' => false,
                'message' => 'حجم سفارشی شما از حجم موجود برای دسته بندی ' . $productCategory->title . ' بیشتر میباشد.'
            ];
        }
        if ($request->has('sizeId')) {
            $sizeId = $request->sizeId;
            $size = Size::query()->find($sizeId);
            if (!$size) {
                return [
                    'success' => false,
                    'message' => 'سایز مورد نظر یافت نشد'
                ];
            }
            $price = $product->sizes()->where('size_id', $size->id)->first()->pivot->price;
        } else {
            $price = $product->price;
        }
        $sentence = null;
        if (isset($data['sentence_id'])) {
            if (!Sentence::query()->find($data['sentence_id'])) {
                return [
                    'success' => false,
                    'message' => 'جمله مورد نظر یافت نشد',
                ];
            }
            if (!$productCategory->getAttribute('printable')) {
                return [
                    'success' => false,
                    'message' => 'محصول انتخابی شما نمیتواند جمله ای بر روی خود داشته باشد.'
                ];
            }
            if ($data['sentence_language'] == "انگلیسی") {
                $sentence = Sentence::query()->find($data['sentence_id'])->english_text;
            } else {
                $sentence = Sentence::query()->find($data['sentence_id'])->farsi_text;
            }
        }
        $product = $product->name;
        if ($request->has('sizeId')) {
            $cart_item = $user->cartItems()->updateOrCreate([
                'product' => $product,
                'frame' => $request->frame,
                'to' => $request->to,
                'from' => $request->from,
                'sentence' => $sentence
            ], [
                'product' => $product,
                'price' => $price,
                'quantity' => $data['quantity'],
                'sentence' => $sentence,
                'frame' => $request->frame,
                'to' => $request->to,
                'from' => $request->from,
                'size' => $size->size,
                'branch_id' => branch()->getAttribute('id')
            ]);
        } else {
            $cart_item = $user->cartItems()->updateOrCreate([
                'product' => $product,
                'frame' => $request->frame,
                'to' => $request->to,
                'from' => $request->from,
                'sentence' => $sentence

            ], [
                'product' => $product,
                'price' => $price,
                'quantity' => $data['quantity'],
                'size' => 's.p',
                'sentence' => $sentence,
                'frame' => $request->frame,
                'to' => $request->to,
                'from' => $request->from,
                'branch_id' => branch()->getAttribute('id')
            ]);
        }

        return [
            'success' => true,
            'cart-item' => $cart_item
        ];
    }

    /**
     * @param CreateCartItemRequest $request
     * @return bool
     */
    protected function allHaveSameBranch(CreateCartItemRequest $request): bool
    {
        $user = $request->user();
        $userCartItems = $user->cartItems;
        if ($userCartItems->count() == 0) {
            return true;
        }
        foreach ($userCartItems as $item) {
            if ($item->branch_id != branch()->getAttribute('id')) {
                return false;
            }
        }
        return true;
    }
}
