<?php


namespace App\Services\ContactUs;


use App\Http\Requests\ContactUsRequest;
use App\Models\ContactUs;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Str;

class MakeContactUs
{
    public function make(ContactUsRequest $request)
    {
        $request->validated();
        $title = $request->title;
        $data = $request->data;
        if ($request->has('image')) {
            $image = $request->image;
            $filename = time() . '_' . Str::random(8) . '.' . $image->getClientOriginalExtension();
            Storage::putFileAs('/', $image, $filename);
            return [
                'success' => true,
                'contact_us' => $this->createContactUs($title, $data, $filename)
            ];
        }
        return [
            'success' => true,
            'contact_us' => $this->createContactUs($title, $data)
        ];
    }

    protected function createContactUs($title, $data, $image = null)
    {
        $first = [
            'title' => $title,
            'data' => $data
        ];
        $second = [
            'title' => $title,
            'data' => $data,
            'image' => $image
        ];
        return $image == null
            ?
            ContactUs::query()->updateOrCreate($first, $first)
            :
            ContactUs::query()->updateOrCreate($first, $second);
    }
}
