<?php


namespace App\Services\CustomerClub;


use App\Http\Requests\CustomerClubRequest;
use App\Models\CustomerClub;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Str;

class CreateOrUpdateCustomerClub
{
    /**
     * @param CustomerClubRequest $request
     * @return array
     */
    public function updateOrCreate(CustomerClubRequest $request): array
    {
        $request->validated();
        $title = $request->title;
        $data = $request->data;
        $right_title = $request->right_title;
        $right_data = $request->right_data;
        $left_title = $request->left_title;
        $left_data = $request->left_data;

        $dataToBeAdded = [
            'title' => $title,
            'data' => $data,
            'right_title' => $right_title,
            'right_data' => $right_data,
            'left_title' => $left_title,
            'left_data' => $left_data
        ];
        if ($request->has('image')) {
            $image = $request->image;
            $filename1 = time() . '_' . Str::random(5) . '.' . $image->getClientOriginalName();
            Storage::putFileAs('/', $image, $filename1);
            $dataToBeAdded += $dataToBeAdded + ['image' => $filename1];
        }
        if ($request->has('bottom_pic')) {
            $bottom_pic = $request->bottom_pic;
            $filename2 = time() . '_' . Str::random(5) . '.' . $bottom_pic->getClientOriginalName();
            Storage::putFileAs('/', $bottom_pic, $filename2);
            $dataToBeAdded += $dataToBeAdded + ['bottom_pic' => $filename2];
        }
        $customer_club = CustomerClub::query()->update($dataToBeAdded);
        return [
            'success' => true,
            'customer_club' => $customer_club
        ];
    }
}
