<?php


namespace App\Services\Order;


use App\Models\Order;
use Illuminate\Http\Request;

class AllTheOrders
{

    public function all()
    {
        $orders = Order::with(['user', 'address'])->whereHas('user')->whereHas('transaction', function ($q) {
            $q->where('status', 'paid');
        })->latest();
        return [
            'success' => true,
            'orders' => $orders->paginate(20)
        ];
    }

    public function filter(Request $request)
    {
        $mobile = $request->mobile;
        $send_type = $request->sendType;
        $status = $request->statusFilter;
        $orders = new Order();
        if ($mobile != '') {
            $orders = $orders->newQuery()->whereHas('user', function ($q) use ($mobile) {
                $q->where('phone_number', 'LIKE', '%' . $mobile . '%');
            });
        }
        if ($send_type != '') {
            $orders = $orders->newQuery()
                ->with(['user', 'address'])
                ->whereHas('user');
            if ($send_type == 't') {
                $orders = $orders->where('send_type', '=', 'دریافت در محل');
            } elseif ($send_type == 'e') {
                $orders = $orders->where('send_type', '=', 'ارسال با پیک');
            }

        }
        if ($status != '') {
            $orders = $orders->with(['user', 'address'])->whereHas('user');
            if ($status == 't') {
                $orders = $orders->where('active', '=', false);
            } elseif ($status == 'd') {
                $orders = $orders->where('active', '=', true);
            }
        }

        return [
            'success' => true,
            'orders' => $orders->with(['user', 'address'])
                ->whereHas('user')
                ->whereHas('transaction', function ($q) {
                    $q->where('status', 'paid');
                })->get()
        ];
    }

    /**
     * @return array
     */
    public function cafeOrders(): array
    {
        $admin = request()->user();
        $isSuperAdmin = $admin->id === 1;
        $baseOrderQuery = Order::with(['user', 'address'])
            ->whereHas('user')
            ->whereHas('transaction', function ($q) {
                $q->where('status', 'paid');
            })
            ->whereHas('orderItems.mainProduct.category', function ($q) {
                $q->where('type', 'CAFE');
            })
            ->latest();
        $orders = $isSuperAdmin ? $baseOrderQuery : $baseOrderQuery->where('branch_id', $admin->branch_id);
        return [
            'success' => true,
            'orders' => $orders->paginate(20),
            'isSuperAdmin' => $isSuperAdmin
        ];
    }

    /**
     * @return array
     */
    public function storeOrders(): array
    {
        $admin = request()->user();
        $isSuperAdmin = $admin->id === 1;
        $baseOrderQuery = Order::with(['user', 'address'])
            ->whereHas('user')
            ->whereHas('transaction', function ($q) {
                $q->where('status', 'paid');
            })
            ->whereHas('orderItems.mainProduct.category', function ($q) {
                $q->where('type', 'STORE');
            })
            ->latest();
        $orders = $isSuperAdmin ? $baseOrderQuery : $baseOrderQuery->where('branch_id', $admin->branch_id);

        return [
            'success' => true,
            'orders' => $orders->paginate(20),
            'isSuperAdmin' => $isSuperAdmin
        ];
    }
}
