<?php


namespace App\Services\Order;


use App\Codes\CodeGenerator;
use App\Http\Requests\CreateOrderRequest;
use App\Models\Address;
use App\Models\Category;
use App\Models\Limitation;
use App\Models\Promotion;

class CreateOrder
{
    protected $branch = null;

    public function __construct()
    {
        $this->branch = findBranch(request()->header('x-branch-id') != 0 ? request()->header('x-branch-id') : null);
    }

    public function save(CreateOrderRequest $request, CodeGenerator $generator)
    {
        $user = $request->user();
        $request->validated();
        if ($request->address_id != null) {
            if (!Address::query()->find($request->address_id)) {
                return [
                    'success' => false,
                    'message' => 'کاربر این آدرس را ندارد',
                ];
            }
        }
        $cart_items = $user->cartItems()->get();
        $price = 0;
        foreach ($cart_items as $item) {
            if ($item->isStoreProduct()) {
                $price += $item->price * $item->quantity;
            } else {
                $price = $price + ($item->price * $item->quantity) * ((100 - $user->rank_promotion) / 100);
            }
            $product = $item->product();
            $category = Category::query()->find($product->category_id);
            if (!$this->checkCategoryCapacity($category, $item->quantity)) {
                return [
                    'success' => false,
                    'message' => 'تعداد سفارش ' . $product->name . ' از حجم معین شده برای آن بیشتر است'
                ];
            }
        }

        $promotion = 0;
        if (isset($request->promotion_code) && ($request->promotion_code != null || $request->promotion_code != '')) {
            $promotion = Promotion::query()
                ->where('promotion_code', '=', $request->promotion_code)
                ->whereNull('deleted_at')
                ->first();
            if (!$promotion) {
                return [
                    'success' => false,
                    'message' => 'کاربر این کد تخفیف را ندارد',
                ];
            }
            if ($promotion->max_promo_limit < $price * $promotion->percent / 100) {
                $price = $price - $promotion->max_promo_limit;
            } else $price = $price - ($price * $promotion->percent / 100);
            if ($request->send_type == 'ارسال با پیک' || $request->send_type == null || $request->send_type == '') {
                $price += $this->branch->getAttribute('delivery_price');
            }
            $order = $user->orders()->create([
                'description' => $request->description,
                'send_type' => ($request->send_type == null || $request->send_type == '') ? 'ارسال با پیک' : $request->send_type,
                'address_id' => $request->address_id,
                'tracking_code' => $generator->trackingCode(),
                'total_price' => $price,
                'promotion_code' => $request->promotion_code,
                'delivery_date' => $request->delivery_date,
                'branch_id' => $this->branch->id
            ]);
            return [
                'success' => true,
                'message' => 'سفارش با موفقیت ثبت گردید',
                'order' => $order,
                'promotion' => $promotion,
            ];
        }
        if ($request->send_type == 'ارسال با پیک' || $request->send_type == null || $request->send_type == '') {
            $price += $this->branch->getAttribute('delivery_price');
        }
        $order = $user->orders()->create([
            'description' => $request->description,
            'send_type' => ($request->send_type == null || $request->send_type == '') ? 'ارسال با پیک' : $request->send_type,
            'address_id' => $request->address_id,
            'tracking_code' => $generator->trackingCode(),
            'total_price' => $price,
            'delivery_date' => $request->delivery_date,
            'branch_id' => $this->branch->id
        ]);
        return [
            'success' => true,
            'message' => 'سفارش با موفقیت ثبت گردید',
            'order' => $order,
            'promotion' => $promotion,
        ];
    }

    protected function checkCategoryCapacity($productCategory, $count): bool
    {
        $limitation = Limitation::query()
            ->where('branch_id', branch()->id)
            ->where('category_id', $productCategory->id)
            ->first();
        if (!is_null($limitation) && $limitation->quantity - $count < 0) {
            return false;
        }
        return true;
    }
}
