<?php


namespace App\Services\OrderItem;


use App\Models\CartItem;
use App\Models\Order;
use App\Models\Transaction;
use App\Models\User;
use Exception;
use Illuminate\Http\Request;
use Shetabit\Multipay\Invoice;
use Shetabit\Payment\Facade\Payment;

class CreateOrderItem
{
    public function save(Request $request)
    {
        $user = $request->user();
        $order = Order::query()->find($user->orders()->get()->last()->id);
        $cartItems = $user->cartItems()->get();
        foreach ($cartItems as $item) {
            $order->orderItems()->create([
                'product' => $item->product,
                'price' => $item->price,
                'quantity' => $item->quantity,
                'sentence' => $item->sentence,
                'frame' => $item->frame,
                'to' => $item->to,
                'from' => $item->from,
                'size' => $item->size,
            ]);
        }
        $user->cartItems()->delete();
        return [
            'success' => true,
            'message' => 'آیتم های سبد خرید به آیتم های سفارش افزوده شد'
        ];

    }

    /**
     * @throws Exception
     */
    public function payment(Request $request)
    {
        $user = $request->user();
        $device = $request->device;
        $request->validate([
            'device' => 'required'
        ]);
        $lastOrder = $user->orders->last();
        if (!$lastOrder) {
            return [
                'success' => false,
                'message' => 'سفارشی ثبت نشده است'
            ];
        }
        if (Transaction::query()->where('order_id', '=', $lastOrder->id)->first()) {
            return [
                'success' => false,
                'message' => 'این سفارش قبلا پرداخت شده است'
            ];
        }
        $amount = $lastOrder->total_price;
        $invoice = new Invoice();
        $invoice->amount($amount);
        $link = Payment::purchase($invoice, function ($driver, $transactionId) use ($amount, $user, $lastOrder, $device) {
            $transaction = new Transaction();
            $transaction->driver = 'زرین پال';
            $transaction->amount = $amount;
            $transaction->user_id = $user->id;
            $transaction->transaction_id = $transactionId;
            $transaction->order_id = $lastOrder->id;
            $transaction->device = $device;
            $transaction->save();
        })->pay()->getAction();
        return [
            'success' => true,
            'link' => $link
        ];
    }
}
