<?php


namespace App\Services\Product;


use App\Models\Admin;
use App\Models\Category;
use App\Models\Product;
use Illuminate\Http\Request;

class AllProducts
{

    public function all(Request $request)
    {
        $products = Product::with('rates')
            ->whereNull('deleted_at')
            ->get();
        if (!($request->user() instanceof Admin)) {
            $products = branch()
                ->products()
                ->with('rates')
                ->withPivot('capacity')
                ->whereNull('deleted_at')
                ->get();

            foreach ($products as $item) {
                $item['is_available'] = $item->pivot->capacity > 0;
            }
        }
        $selectedProducts = [];
        foreach ($products as $item) {
            $category = Category::query()->find($item['category_id']);
            if ($category && $category->type == 'CAFE') {
                array_push($selectedProducts, $item);
                $item ['category'] = $category;
            }
        }
        return [
            'success' => true,
            'products' => $selectedProducts,
        ];
    }

    public function filter(Request $request)
    {
        $name = $request->name;
        $ingredient = $request->ingredient;
        $products = Product::with('rates');

        if ($name != '') {
            $products = $products->where('name', 'like', '%' . $name . '%');
        }
        if ($ingredient != '') {
            $products = $products->where('ingredient', 'like', '%' . $ingredient . '%');
        }
        $products = $products->get();
        $selectedProducts = [];
        if ($products->count() != 0) {
            foreach ($products as $item) {
                $category = Category::query()->find($item['category_id']);
                if ($category) {
                    array_push($selectedProducts, $item);
                    $item ['category'] = $category;
                }
            }
        }
        return [
            'success' => true,
            'products' => $products
        ];
    }
}
