<?php


namespace App\Services\Product;


use App\Models\BeanType;
use App\Models\Category;
use App\Models\CoffeeType;
use App\Models\GrowthPart;
use App\Models\MillType;
use App\Models\Product;
use App\Services\Filter\AllFilters;

class AllStoreProducts
{
    protected $growth_parts;
    protected $coffee_types;
    protected $bean_types;
    protected $mill_types;

    public function __construct()
    {
        $this->growth_parts = new GrowthPart();
        $this->coffee_types = new CoffeeType();
        $this->bean_types = new BeanType();
        $this->mill_types = new MillType();
    }

    /**
     * @return array
     */
    public function all(): array
    {
        $products = Product::query()
            ->with(['growthParts', 'coffeeTypes', 'beanTypes', 'millTypes'])
            ->whereNull('deleted_at')
            ->get();
        $filteredProducts = [];
        foreach ($products as $product) {
            if (!$product->isCafe()) {
                $product['category'] = Category::query()->find($product->category_id);
                $filteredProducts[] = $product;
            }

        }

        return [
            'success' => true,
            'products' => $filteredProducts,
            'growthParts' => (new AllFilters($this->growth_parts))->all()['data'],
            'millTypes' => (new AllFilters($this->mill_types))->all()['data'],
            'beanTypes' => (new AllFilters($this->bean_types))->all()['data'],
            'coffeeTypes' => (new AllFilters($this->coffee_types))->all()['data']
        ];
    }
}
