<?php


namespace App\Services\Product;


use App\Http\Requests\CreateProductRequest;
use App\Models\Category;
use App\Models\Product;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Str;

class CreateProduct
{
    /**
     * @param CreateProductRequest $request
     * @return array|bool[]
     */
    public function save(CreateProductRequest $request): array
    {
        $request->validated();
        $category_id = $request->category_id;
        $category = Category::query()->find($category_id);
        if (!$category) {
            return [
                'success' => false,
                'message' => 'دسته بندی مورد نظر یافت نشد'
            ];
        }
        $product = new Product();
        if ($request->has('image')) {
            $filename = time() . '_' . Str::random(5) . '.' . $request->image->getClientOriginalExtension();
            Storage::putFileAs('/', $request->image, $filename);
            $product->image = $filename;
        }
        $product->category_id = $category_id;
        $product->name = $request->name;
        $product->ingredient = $request->ingredient !== null ? $request->ingredient : null;
        $product->save();
        if ($request->has('prices')) {
            $prices = $request->prices;
            $data = [];
            foreach ($prices as $price) {
                $data[$price['size']] = ['price' => $price['price']];
            }
            $product->sizes()->sync($data);
        }
        if ($request->has('price')) {
            $product->price = $request->price;
            $product->save();
        }

        $category->update([
            'category_id' => $product->id,
        ]);
        return [
            'success' => true,
        ];
    }
}
