<?php


namespace App\Services\Product;


use App\Http\Requests\CreateStoreProductRequest;
use App\Models\BeanType;
use App\Models\Category;
use App\Models\CoffeeType;
use App\Models\GrowthPart;
use App\Models\MillType;
use App\Models\Product;
use App\Models\ProductMeta;
use Exception;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Str;

class CreateStoreProduct
{
    /**
     * @param CreateStoreProductRequest $request
     * @return array
     * @throws Exception
     */
    public function create(CreateStoreProductRequest $request): array
    {
        $request->validated();
        $category = Category::query()->find($request->category_id);
        $this->checkCategory($category);
        $image = $request->image;
        $filename = time() . '_' . Str::random(5) . '.' . $image->getClientOriginalExtension();
        $path = '/';
        $product = Product::query()->updateOrCreate([
            'name' => $request->name
        ], [
            'category_id' => $category->id,
            'name' => $request->name,
            'price' => $request->price,
            'image' => $filename
        ]);

        Storage::putFileAs($path, $image, $filename);
        $metadata = [];
        if ($request->has('mill_type')) {
            array_push($metadata, [
                'filter_id' => $request->mill_type,
                'product_id' => $product->id,
                'filter_type' => MillType::class
            ]);
        }
        if ($request->has('growth_part')) {
            array_push($metadata, [
                'filter_id' => $request->growth_part,
                'product_id' => $product->id,
                'filter_type' => GrowthPart::class
            ]);
        }
        if ($request->has('coffee_type')) {
            array_push($metadata, [
                'filter_id' => $request->coffee_type,
                'product_id' => $product->id,
                'filter_type' => CoffeeType::class
            ]);
        }
        if ($request->has('bean_type')) {
            array_push($metadata, [
                'filter_id' => $request->bean_type,
                'product_id' => $product->id,
                'filter_type' => BeanType::class
            ]);
        }

        foreach ($metadata as $data) {
            ProductMeta::query()->create($data);
        }

        return [
            'success' => true,
            'product' => $product->load(['growthParts', 'coffeeTypes', 'beanTypes', 'millTypes'])
        ];
    }

    /**
     * @param $categoryObj
     * @throws Exception
     */
    protected function checkCategory($categoryObj)
    {
        if (!$categoryObj) {
            throw new Exception('دسته بندی یافت نشد.', 400);
        }
    }
}
