<?php


namespace App\Services\Product;


use App\Http\Requests\UpdateProductRequest;
use App\Models\Category;
use App\Models\Product;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Str;

class UpdateProduct
{
    public function update(Request $request, $id)
    {
        $product = Product::query()->find($id);
        if (!$product) {
            return [
                'success' => false,
                'message' => 'محصول مورد نظر یافت نشد'
            ];
        }
        $category_id = $request->category_id;
        $category = Category::query()->find($category_id);
        if (!$category) {
            return [
                'success' => false,
                'message' => 'دسته بندی مورد نظر یافت نشد'
            ];
        }
        $name = $request->name;
        $ingredient = $request->ingredient === null ? '' : $request->ingredient;

        $image = $request->image;
        if ($image !== null) {
            $filename = time() . '_' . Str::random(5) . '.' . $image->getClientOriginalExtension();
            Storage::putFileAs('/', $image, $filename);
            $product->image = $filename;
        }
        $product->name = $name;
        $product->ingredient = $ingredient;
        $product->save();
        $prices = $request->prices;

        if ($prices !== null) {
            foreach ($prices as $price) {
                $product->updatePivot($product->id, $price['size'], $price['price']);
            }
        }
        return [
            'success' => true,
            'product' => $product,
        ];
    }
}
