<?php


namespace App\Services\Product;


use App\Http\Requests\UpdateStoreProductRequest;
use App\Models\Category;
use App\Models\Product;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Str;

class UpdateStoreProduct
{
    protected $category;
    public function update(UpdateStoreProductRequest $request, $id): array
    {
        $product = Product::query()->find($id);
        if (!$product) {
            return [
                'success' => false,
                'message' => 'محصول مورد نظر شما یافت نشد'
            ];
        }
        $request->validated();
        if ($request->has('name')) {
            $product->name = $request->name;
        }
        if ($request->has('category_id')) {
            if ($this->categoryExists($request->category_id)){
                $product->category_id = $this->category->id;
            }
        }
        if ($request->has('price')) {
            $product->price = $request->price;
        }

        if ($request->has('image')) {
            $image = $request->image;
            $filename = time() . '_' . Str::random(5) . '.' . $image->getClientOriginalExtension();
            $product->image = $filename;
            Storage::putFileAs('/', $image, $filename);
        }

        return [
            'success' => true,
            'saved' => $product->save()
        ];
    }

    /**
     * @param $categoryId
     * @return bool
     */
    protected function categoryExists($categoryId): bool
    {
        $category = Category::query()->find($categoryId);
        if (!is_null($category)) {
            $this->category = $category;
        }
        return !is_null($categoryId);
    }
}
