<?php


namespace App\Services\Profile;


use App\Http\Requests\CreateProfileRequest;
use App\Models\Profile;

class ProfileService
{
    public static function all()
    {
        $profiles = Profile::with('user')->get();
        return [
            'success' => true,
            'profiles' => $profiles
        ];
    }

    public static function userProfile()
    {
        $profile = request()->user()->profile;
        return [
            'success' => true,
            'profile' => $profile
        ];
    }

    public static function create(CreateProfileRequest $request)
    {
        $request->validated();
        $profile = $request->user()->profile()->create([
            'city' => $request->city,
            'gender' => $request->gender,
            'birthdate' => $request->birthdate,
            'province' => $request->province
        ]);
        return [
            'success' => true,
            'profile' => $profile->load('user')
        ];
    }

    public static function find($id)
    {
        $profile = Profile::query()->find($id);
        if (!$profile) {
            return [
                'success' => false,
                'message' => 'پروفایل مورد نظر شما یافت نشد'
            ];
        }
        return [
            'success' => true,
            'profile' => $profile->load('user')
        ];
    }

    public static function update(CreateProfileRequest $request, $id)
    {
        $request->validated();
        $profile = Profile::query()->find($id);
        if (!$profile) {
            return [
                'success' => false,
                'message' => 'پروفایل مورد نظر شما یافت نشد'
            ];
        }
        $profile->update([
            'city' => $request->city,
            'gender' => $request->gender,
            'birthdate' => $request->birthdate,
            'province' => $request->province
        ]);
        return [
            'success' => true
        ];
    }

    public static function delete($id)
    {
        $profile = Profile::query()->find($id);
        if (!$profile) {
            return [
                'success' => false,
                'message' => 'پروفایل مورد نظر شما یافت نشد'
            ];
        }
        $profile->forceDelete();
        return ['success' => true];
    }
}
