<?php


namespace App\Services\Promotion;


use App\Codes\CodeGenerator;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Str;

class CreatePromotion
{
    public function save(Request $request, CodeGenerator $generator)
    {
        $user = $request->user();
        $data = $request->validate([
            'max_promo_limit' => 'required|integer',
            'percent' => 'required|integer',
        ]);
        $promotion = $user->promotions()->updateOrCreate([
            'max_promo_limit' => $data['max_promo_limit'],
            'percent' => $data['percent'],
            'promotion_code' => $generator->promotionCode()
        ]);
        return [
            'success' => true,
            'promotion' => $promotion,
        ];
    }

    public function dispatch(Request $request)
    {
        $list = $request->list;
        $maxPromoLimit = $request->max_promo_limit;
        $percent = $request->percent;

        foreach ($list as $item) {
            $promotionCode = $this->codeGenerator();
            $user = User::find($item);
            $user->promotions()->create([
                'max_promo_limit' => $maxPromoLimit,
                'percent' => $percent,
                'promotion_code' => $promotionCode
            ]);
            $user->notifications()->create([
                'text' => 'کد تخفیف ' . $promotionCode . ' برای شما قابل استفاده است'
            ]);
        }
        return [
            'success' => true
        ];
    }

    public function dispatchAll(Request $request)
    {
        $users = User::all();
        $maxPromoLimit = $request->max_promo_limit;
        $percent = $request->percent;
        foreach ($users as $user) {
            $promotionCode = $this->codeGenerator();
            $user->promotions()->create([
                'max_promo_limit' => $maxPromoLimit,
                'percent' => $percent,
                'promotion_code' => $promotionCode
            ]);
            $user->notifications()->create([
                'text' => 'کد تخفیف ' . $promotionCode . ' برای شما قابل استفاده است'
            ]);
        }
        return [
            'success' => true
        ];
    }

    public function codeGenerator()
    {
        return 'PROMO' . Str::random(7);
    }
}
