<?php


namespace App\Services\Transaction;


use App\Models\Category;
use App\Models\Limitation;
use App\Models\Transaction;
use App\Models\User;
use Exception;
use Illuminate\Http\Request;
use Kavenegar\Exceptions\ApiException;
use Kavenegar\KavenegarApi;
use Shetabit\Multipay\Exceptions\PurchaseFailedException;
use Shetabit\Payment\Facade\Payment;

class ConfirmGateway
{
    /**
     * @param Request $request
     * @return array
     */
    public function confirm(Request $request): array
    {
        $transaction = Transaction::query()->where('transaction_id', $request->Authority)->first();
        if (!$transaction) {
            return [
                'success' => false,
                'message' => 'تراکنش یافت نشد'
            ];
        }
        $transaction_id = $transaction->transaction_id;
        $amount = $transaction->amount;
        try {
            $receipt = Payment::amount($amount)->transactionId($transaction_id)->verify();
            $transaction->ref_id = $receipt->getReferenceId();
            $transaction->status = 'paid';
            $transaction->save();
            $user = User::query()->find($transaction->user_id);
            $order = $user->orders()->get()->last();
            $cartItems = $user->cartItems()->get();
            foreach ($cartItems as $item) {
                $order->orderItems()->create([
                    'product' => $item->product,
                    'price' => $item->price,
                    'quantity' => $item->quantity,
                    'sentence' => $item->sentence,
                    'frame' => $item->frame,
                    'to' => $item->to,
                    'from' => $item->from,
                    'size' => $item->size,
                ]);
            }
            $this->handleCategoryCapacities($user);
            $user->cartItems()->delete();
            $service = new KavenegarApi(config('kavenegar.apikey'));
            $service->VerifyLookup($user->getAttribute('phone_number'), $user->getAttribute('firstname'), null, null, 'ORDERCREATED');
            return [
                'success' => true,
                'receipt' => $transaction->ref_id,
                'message' => 'تراکنش موفقیت آمیز بود'
            ];
        } catch (PurchaseFailedException $exception) {
            $transaction->status = 'failed';
            $transaction->save();
            return [
                'success' => true,
                'message' => $exception->getMessage()
            ];
        } catch (ApiException | Exception $exception) {
            return [
                'success' => true,
                'message' => $exception->getMessage()
            ];
        }
    }
    protected function handleCategoryCapacities($user)
    {
        $cartItems = $user->cartItems;
        foreach ($cartItems as $item) {
            $product = $item->product();
            $category = Category::query()->find($product->category_id);
            $limitation = Limitation::query()
                ->where('branch_id', branch()->getAttribute('id'))
                ->where('category_id', $category->getAttribute('id'))
                ->first();
            $limitation->decrement('quantity', $item->quantity);
        }
    }
}
