<?php


namespace App\Services\Transaction;

use Exception;
use Illuminate\Http\Request;
use Shetabit\Multipay\Invoice;
use Shetabit\Payment\Facade\Payment;


class PaymentGateway
{
    public function pay(Request $request)
    {
        $user = $request->user();
        $order = $user->orders()->get()->last();
        try {
            $invoice = new Invoice();
            $amount = $order->total_price;
            $request->validate([
                'device' => 'required|boolean'
            ]);
            return [
                'success' => true,
                'payment' => Payment::purchase(
                    $invoice->amount($amount),
                    function ($driver, $transactionId) use ($amount, $order, $request) {
                        $order->transaction()->create([
                            'transaction_id' => $transactionId,
                            'driver' => $driver,
                            'amount' => $amount,
                            'device' => $request['device'],
                        ]);
                    }
                )->pay()->getAction(),
            ];
        } catch (Exception $e) {
            return [
                'success' => false,
                'error' => $e->getTrace(),
            ];
        }
    }
}
