<?php


namespace App\Services\User;


use App\Models\User;
use Carbon\Carbon;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Http\Request;

class AllUsers
{

    public function all()
    {
        $users = User::with(['addresses', 'orders', 'referrals', 'promotions', 'notifications', 'profile']);
        if (request()->hasHeader('isNotificationRequest')) {
            $users = $users->whereNull('deleted_at')->get();
        } else {
            $users = $users->whereNull('deleted_at')->paginate(10);
        }
        return [
            'success' => true,
            'users' => $users,
        ];
    }

    public function filter(Request $request)
    {
        $firstname = $request->firstname;
        $lastname = $request->lastname;
        $phone_number = $request->phone_number;
        $status = $request->status;
        $first_date = $request->first_date;
        $second_date = $request->second_date;
        $gender = $request->gender;
        $city = $request->city;
        $province = $request->province;
        $users = new User();
        if ($firstname != '') {
            $users = $users->newQuery()->where('firstname', 'like', '%' . $firstname . '%');
        }
        if ($lastname != '') {
            $users = $users->newQuery()->where('lastname', 'like', '%' . $lastname . '%');
        }
        if ($phone_number != '') {
            $users = $users->newQuery()->where('phone_number', 'like', '%' . $phone_number . '%');
        }
        if ($first_date != '') {
            $users = $users->newQuery()->whereDate('created_at', '>=', $first_date);
        }
        if ($second_date != '') {
            $users = $users->newQuery()->whereDate('created_at', '<=', $second_date);
        }
        if ($gender != '') {
            $users = $users->newQuery()->whereHas('profile', function ($q) use ($gender) {
                $q->where('gender', $gender);
            });
        }
        if ($city != '') {
            $users = $users->newQuery()->whereHas('profile', function ($q) use ($city) {
                $q->where('city', $city);
            });
        }

        if ($province != '') {
            $users = $users->newQuery()->whereHas('profile', function ($q) use ($province) {
                $q->where('province', $province);
            });
        }
        if ($status != '') {
            $users = $users->where('active', $status);
        }

        return [
            'success' => true,
            'users' => $users->with('profile')->get(),
        ];
    }
}
