<?php


namespace App\Services\User;


use App\Codes\CodeGenerator;
use App\Http\Requests\CreateUserRequest;
use App\Models\User;
use App\Models\Verification;

class CreateUser
{
    public function save(CreateUserRequest $request, CodeGenerator $generator)
    {
        $request->validated();
        $firstname = $request->firstname;
        $lastname = $request->lastname;
        $phone_number = $request->phone_number;
        $city = $request->city;
        $gender = $request->gender;
        $birthdate = $request->birthdate;
        $province = $request->province;
        $referral_code = $request->has('referral_code') ? $request->referral_code : null;
        $verification = Verification::query()
            ->where('phone_number', '=', $phone_number)
            ->where('verified', true)
            ->first();
        if (!$verification) {
            return [
                'success' => false,
                'message' => 'شماره موبایل کاربر هنوز تایید نشده است',
            ];
        }
        $user = User::query()
            ->where('phone_number', $phone_number)
            ->where('deleted_at', null)
            ->first();
        if ($user) {
            return [
                'success' => false,
                'message' => 'این کاربر قبلا با این اطلاعات ثبت نام کرده است'
            ];
        }
        if ($referral_code != null) {
            $secondUser = User::query()->where('referral_code', $referral_code)->first();
            if (!$secondUser) {
                return [
                    'success' => false,
                    'message' => 'کد معرفی وارد شده معتبر نمیباشد'
                ];
            }
            $user = User::query()->create([
                'firstname' => $firstname,
                'lastname' => $lastname,
                'phone_number' => $phone_number,
                'referral_code' => $generator->referralCode(),
            ]);
            $user->profile()->create([
                'city' => $city,
                'gender' => $gender,
                'birthdate' => $birthdate,
                'province' => $province
            ]);
            $token = $user->createToken('ApiToken')->plainTextToken;
            $user->referrals()->updateOrCreate([
                'referral_id' => $secondUser->id,
            ]);
            if ($secondUser->credit != null) {
                $credit = $secondUser->credit;
                $credit->value++;
                $credit->save();
            } else {
                $secondUser->credit()->create([
                    'value' => 1
                ]);
            }
            return [
                'success' => true,
                'message' => 'کاربر با موفقیت ایجاد شد و کد معرفی وارد شده معتبر است',
                'user' => $user->load('profile'),
                'referral_user' => $secondUser,
                'token' => $token,
            ];
        }
        $user = User::query()->create([
            'firstname' => $firstname,
            'lastname' => $lastname,
            'phone_number' => $phone_number,
            'referral_code' => $generator->referralCode(),
        ]);
        $user->profile()->create([
            'city' => $city,
            'gender' => $gender,
            'birthdate' => $birthdate,
            'province' => $province
        ]);
        $token = $user->createToken('ApiToken')->plainTextToken;
        return [
            'success' => true,
            'message' => 'کاربر با موفقیت ایجاد شد',
            'user' => $user->load('profile'),
            'token' => $token,
        ];
    }
}
