<?php


namespace App\Services\WebsitePage;

use Exception;
use Illuminate\Http\Request;

class Handler
{
    protected $response;

    /**
     * @param Request $request
     * @return array
     * @throws Exception
     */
    public function handle(Request $request): array
    {
        $page = $request->query('page');
        switch ($page) {
            case "MAIN_PAGE":
                $this->setResponse($this->handleMainPage());
                break;
            case "STORE":
                $this->setResponse($this->handleStore());
                break;
            case "CLUB":
                $this->setResponse($this->customerClub());
                break;
            case "ABOUT_US":
                $this->setResponse($this->handleAboutUs());
                break;
            case "CONTACT_US":
                $this->setResponse($this->handleContactUs());
                break;
            case "SENTENCES":
                $this->setResponse($this->handleSentences());
                break;
            case "FAQ":
                $this->setResponse($this->handleFaq());
                break;
            default:
                throw new Exception('صفحه مورد نظر یافت نشد.', 404);
        }
        return $this->handleResponse($this->getResponse(), $page);
    }

    /**
     * @return array
     */
    protected function handleMainPage(): array
    {
        return [
            'banners' => Reducer::websiteSliders(),
            'products' => Reducer::branchProducts(),
            'most_bought' => Reducer::mostBought(),
            'insta_pics' => Reducer::bottomPics()
        ];
    }

    /**
     * @return array
     */
    protected function handleStore(): array
    {
        return [
            'categories' => Reducer::loadCategoriesWithProducts()
        ];
    }

    /**
     * @return array
     */
    protected function customerClub(): array
    {
        return [
            'club_faqs' => Reducer::customerClubFaq(),
            'customer_club' => Reducer::customerClubData()
        ];
    }

    /**
     * @return array
     */
    protected function handleAboutUs(): array
    {
        return [
            'about_us' => Reducer::aboutUs()
        ];
    }

    /**
     * @return array
     */
    protected function handleContactUs(): array
    {
        return [
            'data' => Reducer::contactUs()
        ];
    }

    /**
     * @return array
     */
    protected function handleSentences(): array
    {
        $data = Reducer::sentences();
        return [
            'categories' => $data['categories']
        ];
    }

    /**
     * @return array
     */
    protected function handleFaq(): array
    {
        return [
            'faq' => Reducer::faq()
        ];
    }

    /**
     * @param $data
     * @param $name
     * @return array
     */
    protected function handleResponse($data, $name): array
    {
        return [
            'success' => true,
            $name => $data
        ];
    }

    protected function setResponse($data)
    {
        $this->response = $data;
    }

    protected function getResponse()
    {
        return $this->response;
    }
}
