<?php


namespace App\Services\WebsitePage;


use App\Models\Branch;
use App\Models\Category;
use App\Models\FooterProduct;
use App\Models\Product;
use App\Models\Rank;
use App\Models\Settings;

class InitService
{
    /**
     * @return array
     */
    public function getData(): array
    {
        return [
            'success' => true,
            'header' => [
                'branches' => $this->getBranches(),
                'store_branches' => $this->getStoreBranches(),
                'products' => $this->getProductWithCategories()
            ],
            'footer' => [
                'products' => $this->getFooterProducts(),
                'settings' => $this->getSettings()
            ],
            'ranks' => $this->getRanks()
        ];
    }

    protected function getBranches()
    {
        return Branch::query()
            ->where('type', 'CAFE')
            ->get();
    }
    protected function getStoreBranches() {
        return Branch::query()
            ->where('type', 'STORE')
            ->get();
    }


    protected function getProductWithCategories()
    {
        $categories = Category::query()
            ->whereNull('deleted_at')
            ->where('category_type', Product::class)
            ->where('type', 'STORE')
            ->get();
        foreach ($categories as $category) {
            $category['products'] = Product::with(['sizes', 'rates', 'branches'])
                ->where('category_id', $category->id)
                ->whereNull('deleted_at')
                ->get();
        }
        return $categories;
    }

    /**
     * @return array
     */
    protected function getFooterProducts(): array
    {
        $products = FooterProduct::with('product')->get()->map(function ($item) {
            return $item->product;
        })->toArray();

        return array_chunk($products, 5);
    }

    public function getRanks()
    {
        return Rank::query()->get();
    }

    /**
     * @return array
     */
    public function getSettings(): array
    {
        $settings = Settings::query()->get()->last();
        return [
            'instagram' => $settings->instagram,
            'telegram' => $settings->telegram,
            'youtube' => $settings->youtube,
            'twitter' => $settings->twitter,
            'linkedIn' => $settings->linkedIn
        ];
    }
}
