<?php


namespace App\Services\WebsitePage;


use App\Models\AboutUs;
use App\Models\Branch;
use App\Models\BranchProduct;
use App\Models\Category;
use App\Models\ContactUs;
use App\Models\CustomerClub;
use App\Models\Faq;
use App\Models\InstaPic;
use App\Models\Limitation;
use App\Models\MostSoldProduct;
use App\Models\OurProduct;
use App\Models\Product;
use App\Models\Sentence;
use App\Models\Settings;
use App\Models\Tag;
use App\Models\WebsiteSlider;

class Reducer
{
    public static function branchProducts()
    {
        $ourProducts = [];
        foreach (OurProduct::with(['product' => function($product) {
            $product->whereNull('deleted_at');
        }, 'product.rates'])->get() as $item) {
            array_push($ourProducts, $item['product']);
        }
        return $ourProducts;

    }

    public static function mostBought()
    {
        $mostSold = [];
        foreach (MostSoldProduct::with(['product' => function($product) {
            $product->whereNull('deleted_at');
        }, 'product.rates'])->get() as $item) {
            array_push($mostSold, $item['product']);
        }
        return $mostSold;
    }

    public static function bottomPics()
    {
        return InstaPic::query()->get();
    }

    public static function websiteSliders()
    {
        return WebsiteSlider::query()->orderBy('priority')->get();
    }

    /**
     * @return array
     */
    public static function loadCategoriesWithProducts(): array
    {
        $categories = Category::query()->where('category_type', Product::class)->whereNull('deleted_at')->get();
        $filteredCategories = [];
        foreach ($categories as $category) {
            $categoryProducts = branch()
                ->products()
                ->with(['sizes', 'rates'])
                ->withPivot('capacity')
                ->where('category_id', $category->id)
                ->whereNull('deleted_at')
                ->get();
            foreach ($categoryProducts as $item) {
                $item['is_available'] = $item->pivot->capacity > 0;
            }
            if ($categoryProducts->count() > 0) {
                $category['products'] = $categoryProducts;
                $filteredCategories[] = $category;
            }

        }
        return $filteredCategories;
    }

    public static function customerClubFaq()
    {
        return Faq::query()->where('page', 'CUSTOMER_CLUB')->get();
    }


    public static function aboutUs()
    {
        return AboutUs::query()->get();
    }

    public static function contactUs(): array
    {
        return [
            'contact_us' => ContactUs::query()->get()->last(),
            'branches' => Branch::query()
//                ->where('active', true)
                ->where('type', 'CAFE')
                ->get(),
            'settings' => Settings::query()->get()->last()
        ];
    }

    public static function sentences(): array
    {
        $categories = Category::query()->where('category_type', Sentence::class)->get();
        foreach ($categories as $item) {
            $item['sentences'] = Sentence::with('tag')->where('category_id', $item->id)->get();
            $item['tags'] = Tag::query()->where('category_id', $item->id)->get();
        }
        return [
            'categories' => $categories
        ];
    }

    public static function faq()
    {
        return Faq::query()->where('page', 'FAQ')->get();
    }

    public static function customerClubData()
    {
        return CustomerClub::query()->get()->last();
    }
}
