<?php

use App\Http\Controllers\AboutUsController;
use App\Http\Controllers\AddressController;
use App\Http\Controllers\AdminController;
use App\Http\Controllers\AssociationController;
use App\Http\Controllers\BeanTypeController;
use App\Http\Controllers\BranchController;
use App\Http\Controllers\CartItemController;
use App\Http\Controllers\CategoryController;
use App\Http\Controllers\CoffeeTypeController;
use App\Http\Controllers\ContactUsController;
use App\Http\Controllers\CreditController;
use App\Http\Controllers\CustomerClubController;
use App\Http\Controllers\CVController;
use App\Http\Controllers\DeliveryPriceController;
use App\Http\Controllers\EventController;
use App\Http\Controllers\FaqController;
use App\Http\Controllers\FilterController;
use App\Http\Controllers\FooterProductController;
use App\Http\Controllers\GrowthPartController;
use App\Http\Controllers\InstaPicController;
use App\Http\Controllers\MillTypeController;
use App\Http\Controllers\MostSoldProductController;
use App\Http\Controllers\NotificationController;
use App\Http\Controllers\OrderController;
use App\Http\Controllers\OrderItemController;
use App\Http\Controllers\OurProductController;
use App\Http\Controllers\PageController;
use App\Http\Controllers\PDFConverterController;
use App\Http\Controllers\PermissionController;
use App\Http\Controllers\ProductController;
use App\Http\Controllers\ProductMetaController;
use App\Http\Controllers\ProfileController;
use App\Http\Controllers\PromotionController;
use App\Http\Controllers\RankController;
use App\Http\Controllers\RateController;
use App\Http\Controllers\RoleController;
use App\Http\Controllers\SearchController;
use App\Http\Controllers\SentenceController;
use App\Http\Controllers\SettingsController;
use App\Http\Controllers\SizeController;
use App\Http\Controllers\SliderController;
use App\Http\Controllers\SupportController;
use App\Http\Controllers\TagController;
use App\Http\Controllers\TermsController;
use App\Http\Controllers\TransactionController;
use App\Http\Controllers\UserController;
use App\Http\Controllers\VerificationController;
use App\Http\Controllers\VideoController;
use App\Http\Controllers\WebsitePageController;
use App\Http\Controllers\WebsiteSliderController;
use App\Services\MainPage;
//use Illuminate\Http\Request;
//use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| is assigned the "api" middleware group. Enjoy building your API!
|
*/

//Verification
Route::post('phone-number-verification', [VerificationController::class, 'phone_number_verification']);
Route::post('confirm-code', [VerificationController::class, 'confirm_code']);
Route::get('logout', [VerificationController::class, 'logout']);

//User
Route::get('/user/init', [UserController::class, 'authUser']);
Route::get('user/{id}', [UserController::class, 'show']);
Route::put('user', [UserController::class, 'update']);
Route::delete('user/{id}', [UserController::class, 'destroy']);
Route::post('activate-user/{id}', [UserController::class, 'activate']);
Route::post('deactivate-user/{id}', [UserController::class, 'deactivate']);
Route::put('update-user-from-panel/{id}', [UserController::class, 'updateUserFromPanel']);
Route::post('change-activation/{id}', [UserController::class, 'toggleActivation']);
Route::post('user', [UserController::class, 'store']);
Route::get('all-users', [UserController::class, 'index']);
Route::post('all-users-with-filter', [UserController::class, 'filter']);
Route::get('user-excel-export', [UserController::class, 'excelExport']);


//Address
Route::resource('address', AddressController::class);
Route::get('/user-address/{id}', [AddressController::class, 'userAddress']);
Route::put('/user-address-update/{id}', [AddressController::class, 'updateAddressFromWebsite']);
Route::delete('/user-address-delete/{id}', [AddressController::class, 'deleteAddress']);
Route::get('admin-read-address/{id}', [AddressController::class, 'adminReadAddress']);

//Notification
Route::resource('notification', NotificationController::class);
Route::get('notifications/mark-as-read', [NotificationController::class, 'mark_as_read']);
Route::get('all-notifications/user/{id}', [NotificationController::class, 'userNotifications']);
Route::post('create-notification-for-user/{id}', [NotificationController::class, 'forUser']);
Route::get('all-notifications/show', [NotificationController::class, 'all']);
Route::delete('delete/notification/{id}', [NotificationController::class, 'deleteById']);
Route::post('/dispatch/notification', [NotificationController::class, 'dispatchNotifications']);
Route::post('/dispatch/notification/all', [NotificationController::class, 'dispatchNotificationAll']);

//Product
Route::resource('product', ProductController::class);
Route::get('product-categories', [ProductController::class, 'product_categories']);
Route::post('filter-products', [ProductController::class, 'filter']);
Route::get('store-products', [ProductController::class, 'storeProducts']);
Route::get('store-categories', [ProductController::class, 'storeCategories']);
Route::post('create-store-product', [ProductController::class, 'createStoreProduct']);
Route::post('update-store-product/{id}', [ProductController::class, 'updateStoreProduct']);
Route::post('/toggle-print/{id}', [ProductController::class, 'togglePrint']);

//Cart Item
Route::resource('cart-item', CartItemController::class);
Route::delete('cart-item-delete/{id}', [CartItemController::class, 'deleteFromWebsite']);
Route::put('/cart-item-sentence-update/{id}', [CartItemController::class, 'updateSentence']);

//Order
Route::resource('order', OrderController::class);
Route::get('all-orders', [OrderController::class, 'all']);
Route::post('order-filter', [OrderController::class, 'filter']);
Route::post('order/change-status/{id}', [OrderController::class, 'changeStatus']);
Route::get('read-order/{id}', [OrderController::class, 'readOrder']);
Route::post('/find-order-by-tracking-code', [OrderController::class, 'findByTrackingCode']);
Route::post('/accept-order', [OrderController::class, 'acceptOrder']);
Route::get('/cafe-orders-excel-export', [OrderController::class, 'export']);
Route::get('/store-orders-excel-export', [OrderController::class, 'exportStoreOrders']);
Route::get('/cafe-orders', [OrderController::class, 'cafeOrders'])->middleware('branch');
Route::get('/store-orders', [OrderController::class, 'storeOrders']);
//Order Item
Route::resource('order-item', OrderItemController::class);

//Category
Route::resource('category', CategoryController::class);
Route::post('update-sentence-category-image/{id}', [CategoryController::class, 'updateSentenceImage']);
Route::post('category-filter', [CategoryController::class, 'filter']);
Route::post('/update-product-category-image/{id}', [CategoryController::class, 'updateCategoryImage']);
Route::post('/change-printable-status/{categoryId}', [CategoryController::class, 'changePrintable']);

//Sentence
Route::resource('sentence', SentenceController::class);
Route::get('sentence-categories', [SentenceController::class, 'sentence_categories']);
Route::get('all-sentences', [SentenceController::class, 'appAllSentences']);
Route::post('sentence-filter', [SentenceController::class, 'filter']);
Route::get('categories-from-panel', [SentenceController::class, 'appAllCategories']);
Route::post('/sentence/{id}/category/edit', [SentenceController::class, 'sentenceCategoryEdit']);
Route::post('/sentence/{id}/tag/edit', [SentenceController::class, 'sentenceTagEdit']);
Route::get('sentence-excel-export', [SentenceController::class, 'excelExport']);

//Search
Route::get('search', [SearchController::class, 'search']);

//Promotion
Route::resource('promotion', PromotionController::class);
Route::get('promotion-codes/user/{id}', [PromotionController::class, 'promotionCodes']);
Route::post('create-promotion/user/{id}', [PromotionController::class, 'adminCreatePromotion']);
Route::post('/dispatch/promotion', [PromotionController::class, 'dispatchPromotions']);
Route::post('/dispatch/promotion/all', [PromotionController::class, 'dispatchPromotionAll']);

//Slider
Route::resource('slider', SliderController::class);
Route::post('/slider/{id}/image-update', [SliderController::class, 'updateImage']);
Route::post('/slider/{id}/title-update', [SliderController::class, 'updateTitle']);
Route::post('/slider/{id}/product-update', [SliderController::class, 'updateProduct']);

//Event
Route::resource('event', EventController::class);

//Pages
Route::get('main-page', [MainPage::class, 'all'])->middleware(['auth:sanctum', 'branch']);
Route::post('cart-page', [MainPage::class, 'cart'])->middleware(['auth:sanctum', 'branch']);
Route::get('history-page', [MainPage::class, 'history'])->middleware('auth:sanctum');
Route::get('welcome-page', [MainPage::class, 'welcome']);
Route::get('sentences-page', [MainPage::class, 'sentences'])->middleware('auth:sanctum');
Route::get('all-orders/{id}', [MainPage::class, 'orders']);
Route::get('dashboard', [MainPage::class, 'dashboard'])->middleware('auth:sanctum');
Route::get('role-permission', [MainPage::class, 'checkboxes'])->middleware('auth:sanctum');

//Terms and Condition
Route::resource('terms', TermsController::class);

//URLs
Route::post('make-settings', [SettingsController::class, 'settings']);
Route::post('update-settings', [SettingsController::class, 'update']);
Route::get('settings', [SettingsController::class, 'read']);

//Sentence Category Tags
Route::resource('tag', TagController::class);
Route::post('/tag/{id}/category/update', [TagController::class, 'categoryUpdate']);

//Administrator
Route::resource('admin', AdminController::class);
Route::post('admin-login', [AdminController::class, 'login']);
Route::post('new-password', [AdminController::class, 'newPassword']);
Route::put('admin-role-update/{id}', [AdminController::class, 'updateRole']);
Route::post('admin-filter', [AdminController::class, 'filter']);
Route::post('/admin/{id}/change-branch', [AdminController::class, 'changeBranch']);
Route::post('/force-password', [AdminController::class, 'forcePassword']);

//User Referrals
Route::get('user-referrals/{id}', [UserController::class, 'referrals']);

//Roles
Route::resource('role', RoleController::class);
Route::post('update-role-accesses/{id}', [RoleController::class, 'updateAccesses']);

//Permissions
Route::resource('permission', PermissionController::class);

//Sizes
Route::resource('size', SizeController::class);
Route::delete('/delete/size/{size}/product/{product}', [SizeController::class, 'deleteProductSize']);

//Transactions
Route::post('payment', [TransactionController::class, 'payment']);
Route::post('confirm', [TransactionController::class, 'confirm']);
Route::get('transaction', [TransactionController::class, 'index']);
Route::get('transactions-excel-export', [TransactionController::class, 'export']);

// Profile
Route::resource('profile', ProfileController::class);
Route::get('/user-profile', [ProfileController::class, 'userProfile']);

// Branches
Route::resource('branch', BranchController::class);
Route::post('/edit-branch/{id}', [BranchController::class, 'update']);
Route::delete('/delete-product/{product_id}/from-branch/{branch_id}', [BranchController::class, 'removeFromBranch']);
Route::post('/add-products-to-branch', [BranchController::class, 'addProducts']);
Route::post('/change-work-hours/{branchId}', [BranchController::class, 'changeWorkHours']);
Route::get('/cafe-categories', [BranchController::class, 'cafeCategories']);
Route::post('/update-quantity', [BranchController::class, 'updateQuantity']);
Route::post('/category-quantity', [BranchController::class, 'categoryQuantity']);
Route::post('/branch/{id}/excuse', [BranchController::class, 'excuse']);
Route::get('/get-branch-{id}-products', [BranchController::class, 'branchProducts']);
Route::post('/handle-product-capacity', [BranchController::class, 'handleProductCapacity']);

// PDF
Route::get('/orders-with-framed-sentences', [PDFConverterController::class, 'orders']);

//// Table Refactor
//Route::get('add-foreign-to-table', function () {
//    return addForeignToTable('cart_items', 'branch_id', 'branches');
//});

Route::patch('/change-order-printed-status', [PDFConverterController::class, 'changeStatus'])->middleware('auth:sanctum');

// Contact Us
Route::get('/contact-us', [ContactUsController::class, 'read']);
Route::post('/contact-us', [ContactUsController::class, 'updateOrCreate']);

// About Us
Route::get('about-us', [AboutUsController::class, 'read']);
Route::post('about-us', [AboutUsController::class, 'updateOrCreate']);
Route::put('/update-about-us-title/{id}', [AboutUsController::class, 'updateTitle']);
Route::post('/update-about-us-image/{id}', [AboutUsController::class, 'updateImage']);
Route::post('/update-about-us-body/{id}', [AboutUsController::class, 'updateBody']);
Route::delete('/delete-about-us/{id}', [AboutUsController::class, 'delete']);
Route::post('/about-us-body/{id}', [AboutUsController::class, 'handleBody']);

// Association
Route::resource('association', AssociationController::class);

// CV
Route::resource('cv', CVController::class);

// Rate a Product
Route::post('rate', [RateController::class, 'rate']);

// Support
Route::get('support', [SupportController::class, 'showAll']);
Route::post('support', [SupportController::class, 'send']);
Route::post('/toggleSupport/{id}', [SupportController::class, 'toggleSupport']);
Route::patch('/toggleSupport/{id}', [SupportController::class, 'toggleSupport']);
Route::get('supports-excel-export', [SupportController::class, 'export']);

// FAQ
Route::resource('faq', FaqController::class);

// Website Pages
Route::get('website-page', [WebsitePageController::class, 'getPage']);
Route::get('/init', [WebsitePageController::class, 'init']);

// Credit
Route::post('increase-credit', [CreditController::class, 'increase'])->middleware('auth:sanctum');
Route::post('decrease-credit', [CreditController::class, 'decrease'])->middleware('auth:sanctum');
Route::post('all-credit', [CreditController::class, 'decrease'])->middleware('auth:sanctum');

// Product Metadata
Route::post('add-metadata', [ProductMetaController::class, 'add']);

// Website Slider
Route::resource('website-slider', WebsiteSliderController::class);
Route::post('/slider/set-priority', [WebsiteSliderController::class, 'setPriority']);

// Instagram Pics
Route::resource('insta-pic', InstaPicController::class);

// Website Search
Route::post('web-search', [SearchController::class, 'webSearch']);

// Filters For Products
Route::resource('growth-part', GrowthPartController::class);
Route::resource('coffee-type', CoffeeTypeController::class);
Route::resource('bean-type', BeanTypeController::class);
Route::resource('mill-type', MillTypeController::class);
Route::get('/filters', [FilterController::class, 'index']);

// Rank
Route::post('/rank-transaction', [RankController::class, 'transaction']);
Route::post('/rank-transaction-verify', [RankController::class, 'verify']);
Route::get('/ranks', [RankController::class, 'index']);
Route::put('/ranks/{id}', [RankController::class, 'update']);

// Customer CLub
Route::resource('customer-club', CustomerClubController::class);

// Video
Route::get('/video', [VideoController::class, 'getVideo']);
Route::post('/video', [VideoController::class, 'makeVideo']);

// Delivery Price
Route::middleware('auth:sanctum')->group(function () {
    Route::get('/delivery-price', [DeliveryPriceController::class, 'getPrice']);
    Route::post('/delivery-price', [DeliveryPriceController::class, 'newPrice']);
});

// Most Sold Products
Route::get('/most-sold-products', [MostSoldProductController::class, 'mostSold']);
Route::post('/update-most-sold-list', [MostSoldProductController::class, 'updateMostSold'])->middleware('auth:sanctum');
Route::delete('/delete-most-sold/{id}', [MostSoldProductController::class, 'delete'])->middleware('auth:sanctum');

// Our Products Section
Route::get('/our-products', [OurProductController::class, 'ourProducts']);
Route::post('/update-our-product-list', [OurProductController::class, 'updateOurProduct'])->middleware('auth:sanctum');
Route::delete('/delete-our-product/{id}', [OurProductController::class, 'delete'])->middleware('auth:sanctum');

// Main Branch Products
Route::get('/main-branch-products', [BranchController::class, 'mainProducts']);

// Important Numeric Data
Route::get('/admin-panel/init', [PageController::class, 'init']);

// Footer Product
Route::prefix('/footer-products')->group(function () {
    Route::get('/all', [FooterProductController::class, 'all']);
    Route::post('/update-list', [FooterProductController::class, 'updateOrCreateFooterProducts']);
    Route::delete('/{id}', [FooterProductController::class, 'destroy']);
});

Route::post('/product-filters-update/{id}', [FilterController::class, 'updateFilters']);


//Route::get('/permission-shit', function (\Illuminate\Http\Request $request) {
////    $persian_action = $request->persian_action;
////    $persian_object = $request->persian_object;
////    $english_action = $request->english_action;
////    $english_object = $request->english_object;
////    $key = $english_action . '-' . $english_object;
////    $title = $persian_action . ' ' .  $persian_object;
////    $permission = \App\Models\Permission::query()->create([
////        'key' => $key,
////        'title' =>  $title
////    ]);
////    return jsonResponse([
////        'success' => true,
////        'permission' => $permission
////    ]);
//    for ($i = 67; $i <= 105; $i++) {
//        \Illuminate\Support\Facades\DB::table('permission_role')->insert([
//            'permission_id' => $i,
//            'role_id' => 10
//        ]);
//    }
//});

//Route::get('migrate', function () {
//    \Illuminate\Support\Facades\Artisan::call('migrate');
//});

//Route::get('/delete-null-from-db', function () {
//    \App\Models\Sentence::query()->whereNotNull('deleted_at')->forceDelete();
//    return jsonResponse([
//        'success' => true,
//        'message' => 'soft deleted sentences where removed.'
//    ]);
//});
//
//Route::get('/delete-long-sentences-from-db', function () {
//    $sentences = \App\Models\Sentence::query()->whereNull('deleted_at')->get();
//    foreach ($sentences as $sentence) {
//        if ($sentence->farsi_text != null && \Illuminate\Support\Str::length($sentence->farsi_text) >= 210) {
//            $sentence->forceDelete();
//        } elseif ($sentence->english_text != null && \Illuminate\Support\Str::length($sentence->english_text) >= 210) {
//            $sentence->forceDelete();
//        }
//    }
//});

/*
 * END of API until here
 */
